@@ -22,6 +22,7 @@
 
 #include <string.h> /* strcmp strlen */
 
+#include "../gwapplicationmanager.h"
 #include "gtktextarea.h"
 #include "gwmsgbox.h"
 #include "gwnotebookmanagmentcallback.h"
@@ -29,10 +30,6 @@
 
 /*! @define	GW_REF_CATEGORIES_EDIT_BOX_MAIN_WINDOW	The main window */
 #define GW_REF_CATEGORIES_EDIT_BOX_MAIN_WINDOW "gw_ref_gw_categories_edit_box_main_window"
-/*! @define	GW_REF_CATEGORIES_EDIT_BOX_CATALOG_INFO	The catalog file info data */
-#define GW_REF_CATEGORIES_EDIT_BOX_CATALOG_INFO "gw_ref_gw_categories_edit_box_catalog_info"
-/*! @define	GW_REF_CATEGORIES_EDIT_BOX_CATEGORIES_LIST_INFO	The categories list data */
-#define GW_REF_CATEGORIES_EDIT_BOX_CATEGORIES_LIST_INFO "gw_ref_gw_categories_edit_box_categories_list_info"
 /*! @define	GW_REF_CATEGORIES_EDIT_BOX_CATEGORY_NAME_ENTRY	The category name */
 #define GW_REF_CATEGORIES_EDIT_BOX_CATEGORY_NAME_ENTRY "gw_ref_gw_categories_edit_box_category_name_entry"
 /*! @define	GW_REF_CATEGORIES_EDIT_BOX_CATEGORY_NAME_ENTRY_TOOLTIPS	The category name tooltips */
@@ -59,8 +56,7 @@
 #define GW_REF_CATEGORIES_EDIT_BOX_CLOSE_BUTTON_TOOLTIPS "gw_ref_gw_categories_edit_box_close_button_toltips"
 
 
-GtkWindow * gw_categories_edit_box_create ( GtkWindow *window, struct catalog_file_info *catalog_info)
-{
+GtkWindow * gw_categories_edit_box_create ( GtkWindow *window, GWDBCatalog *catalog) {
 	/* This window must be single, this property may be changed */
 	static GtkWidget *w = NULL;
 	GtkWidget *vb, *hb, *scr, *list, *bt, *hsp, *ent, *lbl, *frm, *txt;
@@ -80,8 +76,7 @@ GtkWindow * gw_categories_edit_box_create ( GtkWindow *window, struct catalog_fi
 	/* Init tooltips */
 	tips = gtk_tooltips_new ( );
 
-	if ( !w )
-	{
+	if ( !w ) {
 		w = gtk_window_new ( GTK_WINDOW_TOPLEVEL);
 		gtk_window_set_modal ( GTK_WINDOW ( w), TRUE);
 		gtk_window_set_transient_for ( GTK_WINDOW ( w), window);
@@ -93,8 +88,6 @@ GtkWindow * gw_categories_edit_box_create ( GtkWindow *window, struct catalog_fi
 		gtk_container_set_border_width ( GTK_CONTAINER ( w), 5);
 
 		gtk_object_set_data ( GTK_OBJECT ( w), GW_REF_CATEGORIES_EDIT_BOX_MAIN_WINDOW, window);
-		gtk_object_set_data ( GTK_OBJECT ( w), GW_REF_CATEGORIES_EDIT_BOX_CATALOG_INFO, catalog_info);
-		gtk_object_set_data ( GTK_OBJECT ( w), GW_REF_CATEGORIES_EDIT_BOX_CATEGORIES_LIST_INFO, catalog_file_info_get_categories ( catalog_info));
 
 		gtk_signal_connect ( GTK_OBJECT ( w), "destroy", GTK_SIGNAL_FUNC (gtk_widget_destroyed), &w);
 
@@ -276,16 +269,13 @@ GtkWindow * gw_categories_edit_box_create ( GtkWindow *window, struct catalog_fi
 		gtk_window_add_accel_group ( GTK_WINDOW ( w), accel);
 	}
 
-	if ( !GTK_WIDGET_VISIBLE ( w) )
-	{
+	if ( !GTK_WIDGET_VISIBLE ( w) ) {
 #ifdef GW_DEBUG_GUI_COMPONENT
 		g_print ( "*** GW - %s (%d) :: %s() : show the window\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
 		gtk_widget_show_all ( w);
-	}
-	else
-	{
+	} else {
 #ifdef GW_DEBUG_GUI_COMPONENT
 		g_print ( "*** GW - %s (%d) :: %s() : destroy the window\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
@@ -299,197 +289,189 @@ GtkWindow * gw_categories_edit_box_create ( GtkWindow *window, struct catalog_fi
 }
 
 
-gint gw_categories_edit_box_load_categories_list ( GtkWindow *w)
-{
-	GList *categories = NULL;
+gint gw_categories_edit_box_load_categories_list ( GtkWindow *w) {
+	GWCatalogPlugin *plugin = NULL;
+	GWDBContext *context = gw_am_get_current_catalog_context ( );
+	GWDBCategory **categories = NULL;
+	gint i = 0;
+	gint result = -1;
 
 
 #ifdef GW_DEBUG_GUI_COMPONENT
 	g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-	if ( w == NULL )
-	{
-		return -1;
-	}
-
-	categories = gw_categories_edit_box_get_categories_list ( w);
-
-	if ( categories != NULL )
-	{
-		categories = g_list_first ( categories);
-
-		if ( g_list_length ( categories) > 1 )
-		{
-			categories = g_list_next ( categories);
-
-			while ( categories != g_list_last ( categories))
-			{
-				gw_categories_edit_box_add_category ( w, categories->data);
-				categories = g_list_next ( categories);
+	if ( w != NULL && context != NULL ) {
+		plugin = (GWCatalogPlugin*)gw_db_context_get_plugin ( context);
+		if ( (categories = plugin->gw_db_catalog_get_db_categories ( context)) != NULL ) {
+			for ( i = 0; categories[i] != NULL; i++ ) {
+				if ( strcmp ( _("none"), gw_db_category_get_name ( categories[i])) != 0 ) {
+					gw_categories_edit_box_add_category ( w, categories[i]);
+				} else {
+					gw_db_category_free ( categories[i]);
+				}
 			}
 
-			gw_categories_edit_box_add_category ( w, categories->data);
+			g_free ( categories);
 		}
+		
+		result = 0;
 	}
 
 	gw_categories_edit_box_set_add_state ( w);
 
-	return 0;
+	return result;
 }
 
 
-gint gw_categories_edit_box_update_click ( GtkWidget *bt, GtkWindow *w)
-{
-	struct category *category = NULL;
+gint gw_categories_edit_box_update_click ( GtkWidget *bt, GtkWindow *w) {
+	GWDBCategory *category = NULL;
+	gint result = -1;
 
 
 #ifdef GW_DEBUG_GUI_COMPONENT
 	g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-	if ( w == NULL )
-	{
-		return -1;
-	}
+	if ( w != NULL ) {
+		if ( (category = gw_categories_edit_box_get_category ( w)) != NULL ) {
+			gw_categories_edit_box_set_category_name ( w, gw_db_category_get_name ( category));
+			gw_categories_edit_box_set_category_description ( w, gw_db_category_get_description ( category));
 
-	category = gw_categories_edit_box_get_category ( w);
+			gw_categories_edit_box_set_update_state ( w);
 
-	if ( category == NULL )
-	{
-		return -1;
-	}
-
-	gw_categories_edit_box_set_category_name ( w, category_get_name ( category));
-	gw_categories_edit_box_set_category_description ( w, category_get_description ( category));
-
-	catalog_file_info_set_ismodified ( gw_categories_edit_box_get_catalog_info ( w), TRUE);
-	gw_categories_edit_box_set_update_state ( w);
-
-	return 0;
-}
-
-
-gint gw_categories_edit_box_remove_click ( GtkWidget *bt, GtkWindow *w)
-{
-	struct category *category = NULL;
-
-
-#ifdef GW_DEBUG_GUI_COMPONENT
-	g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
-#endif
-
-	if ( w == NULL )
-	{
-		return -1;
-	}
-
-	category = gw_categories_edit_box_get_category ( w);
-
-	if ( category == NULL )
-	{
-		return -1;
-	}
-
-	if ( !category_can_removed ( category) )
-	{
-		gw_msg_box_create ( w, _( "Remove category"), _( "Can't remove this category. It's used by an item."));
-
-		return -1;
-	}
-
-	if ( gw_categories_edit_box_remove_category ( w) != -1 )
-	{
-		catalog_file_info_set_ismodified ( gw_categories_edit_box_get_catalog_info ( w), TRUE);
-	}
-
-	gw_categories_edit_box_set_category_name ( w, "");
-	gw_categories_edit_box_set_category_description ( w, "");
-
-	gw_categories_edit_box_set_add_state ( w);
-
-	return 0;
-}
-
-
-gint gw_categories_edit_box_add_update_click ( GtkWidget *bt, GtkWindow *w)
-{
-#ifdef GW_DEBUG_GUI_COMPONENT
-	g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
-#endif
-
-	if ( gw_categories_edit_box_get_isadd_state ( w) )
-	{
-		if ( gw_categories_edit_box_add_category ( w, NULL) != -1 )
-		{
-			catalog_file_info_set_ismodified ( gw_categories_edit_box_get_catalog_info ( w), TRUE);
+			result = 0;
 		}
-
-		gw_categories_edit_box_set_category_name ( w, "");
-		gw_categories_edit_box_set_category_description ( w, "");
-
-		gw_categories_edit_box_set_add_state ( w);
-		gw_notebook_managment_refresh_categories ( gw_categories_edit_box_get_main_window ( w));
-
-		return 0;
 	}
-	else { if ( gw_categories_edit_box_get_isupdate_state ( w) )
-	{
-		gw_categories_edit_box_update_category ( w);
-		catalog_file_info_set_ismodified ( gw_categories_edit_box_get_catalog_info ( w), TRUE);
-		gw_categories_edit_box_set_category_name ( w, "");
-		gw_categories_edit_box_set_category_description ( w, "");
 
-		gw_categories_edit_box_set_add_state ( w);
-		gw_notebook_managment_refresh_categories ( gw_categories_edit_box_get_main_window ( w));
-
-		return 0;
-	}
-	else
-	{
-		/* If they're no state */
-		return -1;
-	}}
-
-	return -1;
+	return result;
 }
 
 
-gboolean gw_categories_edit_box_list_select_row ( GtkCList *list, gint line, gint column, GdkEvent *event, GtkWindow *w)
-{
+gint gw_categories_edit_box_remove_click ( GtkWidget *bt, GtkWindow *w) {
+	GWCatalogPlugin *plugin = NULL;
+	GWDBContext *context = gw_am_get_current_catalog_context ( );
+	GWDBCategory *category = NULL, *real_category = NULL;
+	gint result = -1;
+
+
+#ifdef GW_DEBUG_GUI_COMPONENT
+	g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
+#endif
+
+	if ( w != NULL ) {
+		if ( (category = gw_categories_edit_box_get_category ( w)) != NULL ) {
+			if ( context != NULL) {
+				if ( (plugin = (GWCatalogPlugin*)gw_db_context_get_plugin ( context)) != NULL) {
+					real_category = plugin->gw_db_catalog_get_db_category ( context, gw_db_category_get_ref ( category));
+					
+					if ( gw_db_category_can_removed ( real_category)) {
+						gw_categories_edit_box_remove_category ( w);
+
+						gw_categories_edit_box_set_category_name ( w, "");
+						gw_categories_edit_box_set_category_description ( w, "");
+
+						gw_categories_edit_box_set_add_state ( w);
+						gw_notebook_managment_refresh_categories ( gw_categories_edit_box_get_main_window ( w));
+
+						result = 0;
+					} else {
+						gw_msg_box_create ( w, _( "Remove category"), _( "Can't remove this category. It's used by an item."));
+					}
+
+					gw_db_category_free ( real_category);
+				} else {
+				}
+			} else {}
+
+//			if ( gw_db_category_can_removed ( category) ) {
+//				gw_categories_edit_box_remove_category ( w);
+//
+//				gw_categories_edit_box_set_category_name ( w, "");
+//				gw_categories_edit_box_set_category_description ( w, "");
+//
+//				gw_categories_edit_box_set_add_state ( w);
+//
+//				result = 0;
+//			} else {
+//				gw_msg_box_create ( w, _( "Remove category"), _( "Can't remove this category. It's used by an item."));
+//			}
+		}
+	}
+
+	return result;
+}
+
+
+gint gw_categories_edit_box_add_update_click ( GtkWidget *bt, GtkWindow *w) {
+	gint result = -1;
+
+
+#ifdef GW_DEBUG_GUI_COMPONENT
+	g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
+#endif
+
+	if ( w != NULL ) {
+		if ( gw_categories_edit_box_get_isadd_state ( w) ) {
+			gw_categories_edit_box_add_category ( w, NULL);
+
+			gw_categories_edit_box_set_category_name ( w, "");
+			gw_categories_edit_box_set_category_description ( w, "");
+	
+			gw_categories_edit_box_set_add_state ( w);
+			gw_notebook_managment_refresh_categories ( gw_categories_edit_box_get_main_window ( w));
+
+			result = 0;
+		} else if ( gw_categories_edit_box_get_isupdate_state ( w) ) {
+			gw_categories_edit_box_update_category ( w);
+
+			gw_categories_edit_box_set_category_name ( w, "");
+			gw_categories_edit_box_set_category_description ( w, "");
+
+			gw_categories_edit_box_set_add_state ( w);
+			gw_notebook_managment_refresh_categories ( gw_categories_edit_box_get_main_window ( w));
+
+			result = 0;
+		} else {
+			/* If they're no state */
+		}
+	}
+
+	return result;
+}
+
+
+gboolean gw_categories_edit_box_list_select_row ( GtkCList *list, gint line, gint column, GdkEvent *event, GtkWindow *w) {
 	GtkButton *bt = NULL;
+	gboolean result = FALSE;
 
 
 #ifdef GW_DEBUG_GUI_COMPONENT
 	g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-	if ( w == NULL )
-	{
-		return FALSE;
+	if ( w != NULL ) {
+		gw_categories_edit_box_set_category_name ( w, "");
+		gw_categories_edit_box_set_category_description ( w, "");
+
+		if ( (bt = gw_categories_edit_box_get_update_category_button ( w)) != NULL ) {
+			gtk_widget_set_sensitive ( GTK_WIDGET ( bt), TRUE);
+		}
+
+		if ( (bt = gw_categories_edit_box_get_remove_category_button ( w)) != NULL ) {
+			gtk_widget_set_sensitive ( GTK_WIDGET ( bt), TRUE);
+		}
+
+		gw_categories_edit_box_set_add_state ( w);
+
+		result = TRUE;
 	}
 
-	gw_categories_edit_box_set_category_name ( w, "");
-	gw_categories_edit_box_set_category_description ( w, "");
-
-	if ( (bt = gw_categories_edit_box_get_update_category_button ( w)) != NULL )
-	{
-		gtk_widget_set_sensitive ( GTK_WIDGET ( bt), TRUE);
-	}
-
-	if ( (bt = gw_categories_edit_box_get_remove_category_button ( w)) != NULL )
-	{
-		gtk_widget_set_sensitive ( GTK_WIDGET ( bt), TRUE);
-	}
-
-	gw_categories_edit_box_set_add_state ( w);
-
-	return TRUE;
+	return result;
 }
 
 
-gint gw_categories_edit_box_set_category_name ( GtkWindow *w, gchar *category_name)
-{
+gint gw_categories_edit_box_set_category_name ( GtkWindow *w, gchar *category_name) {
 	GtkEntry *entry = NULL;
 	gchar *text_utf8 = NULL;
 	gint result = -1;
@@ -499,14 +481,12 @@ gint gw_categories_edit_box_set_category_name ( GtkWindow *w, gchar *category_na
 	g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-	if ( w != NULL )
-	{
-		if ( (entry = gtk_object_get_data ( GTK_OBJECT ( w), GW_REF_CATEGORIES_EDIT_BOX_CATEGORY_NAME_ENTRY)) != NULL )
-		{
+	if ( w != NULL ) {
+		if ( (entry = gtk_object_get_data ( GTK_OBJECT ( w), GW_REF_CATEGORIES_EDIT_BOX_CATEGORY_NAME_ENTRY)) != NULL ) {
 			g_strdup_to_gtk_text ( category_name, text_utf8);
 			gtk_entry_set_text ( entry, text_utf8);
 			g_free ( text_utf8);
-	
+
 			result = 0;
 		}
 	}
@@ -515,8 +495,7 @@ gint gw_categories_edit_box_set_category_name ( GtkWindow *w, gchar *category_na
 }
 
 
-gint gw_categories_edit_box_set_category_description ( GtkWindow *w, gchar *category_description)
-{
+gint gw_categories_edit_box_set_category_description ( GtkWindow *w, gchar *category_description) {
 	GtkTextArea *txt = NULL;
 	gint result = -1;
 
@@ -525,10 +504,8 @@ gint gw_categories_edit_box_set_category_description ( GtkWindow *w, gchar *cate
 	g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-	if ( w != NULL )
-	{
-		if ( (txt = gtk_object_get_data ( GTK_OBJECT ( w), GW_REF_CATEGORIES_EDIT_BOX_CATEGORY_DESCRIPTION_TEXT)) != NULL )
-		{
+	if ( w != NULL ) {
+		if ( (txt = gtk_object_get_data ( GTK_OBJECT ( w), GW_REF_CATEGORIES_EDIT_BOX_CATEGORY_DESCRIPTION_TEXT)) != NULL ) {
 			gtk_text_area_clear ( GTK_TEXT_AREA ( txt));
 			gtk_text_area_insert ( GTK_TEXT_AREA ( txt), category_description);
 
@@ -540,8 +517,7 @@ gint gw_categories_edit_box_set_category_description ( GtkWindow *w, gchar *cate
 }
 
 
-gint gw_categories_edit_box_set_add_state ( GtkWindow *w)
-{
+gint gw_categories_edit_box_set_add_state ( GtkWindow *w) {
 	GtkButton *bt = NULL;
 	gchar *text_utf8 = NULL;
 	gint result = -1;
@@ -551,10 +527,8 @@ gint gw_categories_edit_box_set_add_state ( GtkWindow *w)
 	g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-	if ( w != NULL )
-	{
-		if ( (bt = gtk_object_get_data ( GTK_OBJECT ( w), GW_REF_CATEGORIES_EDIT_BOX_ADD_UPDATE_BUTTON)) != NULL )
-		{
+	if ( w != NULL ) {
+		if ( (bt = gtk_object_get_data ( GTK_OBJECT ( w), GW_REF_CATEGORIES_EDIT_BOX_ADD_UPDATE_BUTTON)) != NULL ) {
 			g_strdup_to_gtk_text ( _( "Add"), text_utf8);
 			gtk_label_set_text ( GTK_LABEL ( GTK_BIN ( bt)->child), text_utf8);
 			g_free ( text_utf8);
@@ -567,8 +541,7 @@ gint gw_categories_edit_box_set_add_state ( GtkWindow *w)
 }
 
 
-gint gw_categories_edit_box_set_update_state ( GtkWindow *w)
-{
+gint gw_categories_edit_box_set_update_state ( GtkWindow *w) {
 	GtkButton *bt = NULL;
 	gchar *text_utf8 = NULL;
 	gint result = -1;
@@ -578,10 +551,8 @@ gint gw_categories_edit_box_set_update_state ( GtkWindow *w)
 	g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-	if ( w != NULL )
-	{
-		if ( (bt = gtk_object_get_data ( GTK_OBJECT ( w), GW_REF_CATEGORIES_EDIT_BOX_ADD_UPDATE_BUTTON)) != NULL )
-		{
+	if ( w != NULL ) {
+		if ( (bt = gtk_object_get_data ( GTK_OBJECT ( w), GW_REF_CATEGORIES_EDIT_BOX_ADD_UPDATE_BUTTON)) != NULL ) {
 			g_strdup_to_gtk_text ( _( "Update"), text_utf8);
 			gtk_label_set_text ( GTK_LABEL ( GTK_BIN ( bt)->child), text_utf8);
 			g_free ( text_utf8);
@@ -594,10 +565,10 @@ gint gw_categories_edit_box_set_update_state ( GtkWindow *w)
 }
 
 
-gint gw_categories_edit_box_add_category ( GtkWindow *w, struct category *p)
-{
-	struct category *category = NULL;
-	struct catalog_file_info *catalog_info = NULL;
+gint gw_categories_edit_box_add_category ( GtkWindow *w, GWDBCategory *p) {
+	GWCatalogPlugin *plugin = NULL;
+	GWDBContext *context = gw_am_get_current_catalog_context ( );
+	GWDBCategory *category = NULL;
 	GtkCList *list = NULL;
 	gchar *info[2];
 	guint row;
@@ -609,41 +580,37 @@ gint gw_categories_edit_box_add_category ( GtkWindow *w, struct category *p)
 		g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-	if ( w != NULL )
-	{
+	if ( w != NULL ) {
 		list = gtk_object_get_data ( GTK_OBJECT ( w), GW_REF_CATEGORIES_EDIT_BOX_CATEGORIES_LIST);
 
 		/* Does one have to leave the program if list is NULL? */
-		if ( p == NULL )
-		{
-			category = category_new ( );
+		if ( p == NULL ) {
+			category = gw_db_category_new ( );
 			category_name = gw_categories_edit_box_get_category_name ( w);
 
-			if ( category_name != NULL )
-			{
-				if ( strlen ( category_name) > 0 )
-				{
-					category_set_name ( category, category_name);
-					category_set_description ( category, gw_categories_edit_box_get_category_description ( w));
-		
-					catalog_info = gw_categories_edit_box_get_catalog_info ( w);
-					catalog_file_info_append_category ( catalog_info, category);
-				}
-				else
-				{
+			if ( category_name != NULL ) {
+				if ( strlen ( category_name) > 0 ) {
+					if ( context != NULL) {
+						plugin = (GWCatalogPlugin*)gw_db_context_get_plugin ( context);
+						gw_db_category_set_name ( category, category_name);
+						gw_db_category_set_description ( category, gw_categories_edit_box_get_category_description ( w));
+
+						plugin->gw_db_catalog_add_db_category ( context, category);
+					}
+				} else {
 					g_free ( category_name);
 				}
 			}
-		}
-		else
-		{
+		} else {
 			category = p;
 		}
 
-		g_strdup_to_gtk_text ( category_get_name ( category), info[0]);
-		g_strdup_to_gtk_text ( category_get_description ( category), info[1]);
+		g_strdup_to_gtk_text ( gw_db_category_get_name ( category), info[0]);
+		g_strdup_to_gtk_text ( gw_db_category_get_description ( category), info[1]);
 		row = gtk_clist_append ( list, info);
-		gtk_clist_set_row_data ( list, row, category);
+		//FIXME memory leak
+//		gtk_clist_set_row_data ( list, row, category);
+		gtk_clist_set_row_data_full ( list, row, category, (GtkDestroyNotify)gw_db_category_free);
 		g_free ( info[0]);
 		g_free ( info[1]);
 
@@ -654,9 +621,10 @@ gint gw_categories_edit_box_add_category ( GtkWindow *w, struct category *p)
 }
 
 
-gint gw_categories_edit_box_update_category ( GtkWindow *w)
-{
-	struct category *category = NULL;
+gint gw_categories_edit_box_update_category ( GtkWindow *w) {
+	GWCatalogPlugin *plugin = NULL;
+	GWDBContext *context = gw_am_get_current_catalog_context ( );
+	GWDBCategory *category = NULL;
 	GtkCList *list = NULL;
 	gchar *text_utf8 = NULL;
 	gint result = -1;
@@ -666,21 +634,20 @@ gint gw_categories_edit_box_update_category ( GtkWindow *w)
 		g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-	if ( w != NULL )
-	{
-		if ( (category = gw_categories_edit_box_get_category ( w)) != NULL )
-		{
-			if ( (list = gtk_object_get_data ( GTK_OBJECT ( w), GW_REF_CATEGORIES_EDIT_BOX_CATEGORIES_LIST)) != NULL )
-			{
-				if ( list->selection != NULL )
-				{
-					category_set_name ( category, gw_categories_edit_box_get_category_name ( w));
-					category_set_description ( category, gw_categories_edit_box_get_category_description ( w));
+	if ( w != NULL && context != NULL ) {
+		if ( (category = gw_categories_edit_box_get_category ( w)) != NULL ) {
+			if ( (list = gtk_object_get_data ( GTK_OBJECT ( w), GW_REF_CATEGORIES_EDIT_BOX_CATEGORIES_LIST)) != NULL ) {
+				if ( list->selection != NULL ) {
+					plugin = (GWCatalogPlugin*)gw_db_context_get_plugin ( context);
+					gw_db_category_set_name ( category, gw_categories_edit_box_get_category_name ( w));
+					gw_db_category_set_description ( category, gw_categories_edit_box_get_category_description ( w));
 
-					g_strdup_to_gtk_text ( category_get_name ( category), text_utf8);
+					plugin->gw_db_category_update ( context, category);
+
+					g_strdup_to_gtk_text ( gw_db_category_get_name ( category), text_utf8);
 					gtk_clist_set_text ( list, (gint)(list->selection->data), 0, text_utf8);
 					g_free ( text_utf8);
-					g_strdup_to_gtk_text ( category_get_description ( category), text_utf8);
+					g_strdup_to_gtk_text ( gw_db_category_get_description ( category), text_utf8);
 					gtk_clist_set_text ( list, (gint)(list->selection->data), 1, text_utf8);
 					g_free ( text_utf8);
 
@@ -690,69 +657,46 @@ gint gw_categories_edit_box_update_category ( GtkWindow *w)
 		}
 	}
 
-	return 0;
-}
-
-
-gint gw_categories_edit_box_remove_category ( GtkWindow *w)
-{
-	struct category *category = NULL;
-	GtkCList *list = NULL;
-	/* Remove category isn't implemented yet. */
-	/*GList *categories = NULL;*/
-	struct catalog_file_info *catalog_info = NULL;
-	gint result = -1;
-
-
-#ifdef GW_DEBUG_GUI_COMPONENT
-		g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
-#endif
-
-	if ( w != NULL )
-	{
-		if ( (category = gw_categories_edit_box_get_category ( w)) != NULL )
-		{
-			if ( (list = gtk_object_get_data ( GTK_OBJECT ( w), GW_REF_CATEGORIES_EDIT_BOX_CATEGORIES_LIST)) != NULL )
-			{
-				if ( list->selection != NULL )
-				{
-					/*categories = gw_categories_edit_box_get_categories_list ( w);*/
-					catalog_info = gw_categories_edit_box_get_catalog_info ( w);
-
-					gtk_clist_remove ( list, (gint)(list->selection->data));
-					catalog_file_info_remove_category ( catalog_info, category);
-					/*g_list_remove ( categories, category);*/
-
-					result = 0;
-				}
-			}
-		}
-	}
-
 	return result;
 }
 
 
-struct catalog_file_info * gw_categories_edit_box_get_catalog_info ( GtkWindow *w)
-{
-	struct catalog_file_info *catalog_info = NULL;
+gint gw_categories_edit_box_remove_category ( GtkWindow *w) {
+	GWCatalogPlugin *plugin = NULL;
+	GWDBContext *context = gw_am_get_current_catalog_context ( );
+	GWDBCategory *category = NULL;
+	GtkCList *list = NULL;
+	/* Remove category isn't implemented yet. */
+	gint result = -1;
 
 
 #ifdef GW_DEBUG_GUI_COMPONENT
 		g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-	if ( w != NULL )
-	{
-		catalog_info = gtk_object_get_data ( GTK_OBJECT ( w), GW_REF_CATEGORIES_EDIT_BOX_CATALOG_INFO);
+	if ( w != NULL ) {
+		if ( (category = gw_categories_edit_box_get_category ( w)) != NULL ) {
+			if ( (list = gtk_object_get_data ( GTK_OBJECT ( w), GW_REF_CATEGORIES_EDIT_BOX_CATEGORIES_LIST)) != NULL ) {
+				if ( list->selection != NULL ) {
+					if ( context != NULL) {
+						plugin = (GWCatalogPlugin*)gw_db_context_get_plugin ( context);
+
+						gtk_clist_remove ( list, (gint)(list->selection->data));
+
+						plugin->gw_db_catalog_remove_db_category ( context, gw_db_category_get_ref ( category));
+
+						result = 0;
+					}
+				}
+			}
+		}
 	}
 
-	return catalog_info;
+	return result;
 }
 
 
-GtkWindow * gw_categories_edit_box_get_main_window ( GtkWindow *w)
-{
+GtkWindow * gw_categories_edit_box_get_main_window ( GtkWindow *w) {
 	GtkWindow *window = NULL;
 
 
@@ -760,8 +704,7 @@ GtkWindow * gw_categories_edit_box_get_main_window ( GtkWindow *w)
 	g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-	if ( w != NULL )
-	{
+	if ( w != NULL ) {
 		window = gtk_object_get_data ( GTK_OBJECT ( w), GW_REF_CATEGORIES_EDIT_BOX_MAIN_WINDOW);
 	}
 
@@ -769,8 +712,7 @@ GtkWindow * gw_categories_edit_box_get_main_window ( GtkWindow *w)
 }
 
 
-GtkButton * gw_categories_edit_box_get_update_category_button ( GtkWindow *w)
-{
+GtkButton * gw_categories_edit_box_get_update_category_button ( GtkWindow *w) {
 	GtkButton *bt = NULL;
 
 
@@ -787,8 +729,7 @@ GtkButton * gw_categories_edit_box_get_update_category_button ( GtkWindow *w)
 }
 
 
-GtkButton * gw_categories_edit_box_get_remove_category_button ( GtkWindow *w)
-{
+GtkButton * gw_categories_edit_box_get_remove_category_button ( GtkWindow *w) {
 	GtkButton *bt = NULL;
 
 
@@ -796,8 +737,7 @@ GtkButton * gw_categories_edit_box_get_remove_category_button ( GtkWindow *w)
 	g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-	if ( w != NULL )
-	{
+	if ( w != NULL ) {
 		bt = GTK_BUTTON ( gtk_object_get_data ( GTK_OBJECT ( w), GW_REF_CATEGORIES_EDIT_BOX_REMOVE_BUTTON));
 	}
 
@@ -805,8 +745,7 @@ GtkButton * gw_categories_edit_box_get_remove_category_button ( GtkWindow *w)
 }
 
 
-GtkButton * gw_categories_edit_box_get_add_update_category_button ( GtkWindow *w)
-{
+GtkButton * gw_categories_edit_box_get_add_update_category_button ( GtkWindow *w) {
 	GtkButton *bt = NULL;
 
 
@@ -814,8 +753,7 @@ GtkButton * gw_categories_edit_box_get_add_update_category_button ( GtkWindow *w
 	g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-	if ( w != NULL )
-	{
+	if ( w != NULL ) {
 		bt = GTK_BUTTON ( gtk_object_get_data ( GTK_OBJECT ( w), GW_REF_CATEGORIES_EDIT_BOX_ADD_UPDATE_BUTTON));
 	}
 
@@ -823,27 +761,8 @@ GtkButton * gw_categories_edit_box_get_add_update_category_button ( GtkWindow *w
 }
 
 
-GList * gw_categories_edit_box_get_categories_list ( GtkWindow *w)
-{
-	GList *list = NULL;
-
-
-#ifdef GW_DEBUG_GUI_COMPONENT
-		g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
-#endif
-
-	if ( w != NULL )
-	{
-		list = gtk_object_get_data ( GTK_OBJECT ( w), GW_REF_CATEGORIES_EDIT_BOX_CATEGORIES_LIST_INFO);
-	}
-
-	return list;
-}
-
-
-struct category * gw_categories_edit_box_get_category ( GtkWindow *w)
-{
-	struct category *category = NULL;
+GWDBCategory * gw_categories_edit_box_get_category ( GtkWindow *w) {
+	GWDBCategory *category = NULL;
 	GtkCList *list = NULL;
 
 
@@ -851,12 +770,9 @@ struct category * gw_categories_edit_box_get_category ( GtkWindow *w)
 		g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-	if ( w != NULL )
-	{
-		if ( (list = gtk_object_get_data ( GTK_OBJECT ( w), GW_REF_CATEGORIES_EDIT_BOX_CATEGORIES_LIST)) != NULL )
-		{
-			if ( list->selection != NULL )
-			{		
+	if ( w != NULL ) {
+		if ( (list = gtk_object_get_data ( GTK_OBJECT ( w), GW_REF_CATEGORIES_EDIT_BOX_CATEGORIES_LIST)) != NULL ) {
+			if ( list->selection != NULL ) {
 				category = gtk_clist_get_row_data ( list, (gint)(list->selection->data));
 			}
 		}
@@ -866,8 +782,7 @@ struct category * gw_categories_edit_box_get_category ( GtkWindow *w)
 }
 
 
-gchar * gw_categories_edit_box_get_category_name ( GtkWindow *w)
-{
+gchar * gw_categories_edit_box_get_category_name ( GtkWindow *w) {
 	GtkEntry *entry = NULL;
 	gchar *category_name = NULL;
 
@@ -876,12 +791,10 @@ gchar * gw_categories_edit_box_get_category_name ( GtkWindow *w)
 		g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-	if ( w != NULL )
-	{
+	if ( w != NULL ) {
 		entry = gtk_object_get_data ( GTK_OBJECT ( w), GW_REF_CATEGORIES_EDIT_BOX_CATEGORY_NAME_ENTRY);
 
-		if ( entry != NULL )
-		{
+		if ( entry != NULL ) {
 			g_strdup_from_gtk_text ( gtk_entry_get_text ( entry), category_name);
 		}
 	}
@@ -890,8 +803,7 @@ gchar * gw_categories_edit_box_get_category_name ( GtkWindow *w)
 }
 
 
-gchar * gw_categories_edit_box_get_category_description ( GtkWindow *w)
-{
+gchar * gw_categories_edit_box_get_category_description ( GtkWindow *w) {
 	GtkTextArea *txt = NULL;
 	gchar *category_description = NULL;
 
@@ -900,12 +812,10 @@ gchar * gw_categories_edit_box_get_category_description ( GtkWindow *w)
 		g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-	if ( w != NULL )
-	{
+	if ( w != NULL ) {
 		txt = gtk_object_get_data ( GTK_OBJECT ( w), GW_REF_CATEGORIES_EDIT_BOX_CATEGORY_DESCRIPTION_TEXT);
 
-		if ( txt != NULL )
-		{
+		if ( txt != NULL ) {
 			category_description = gtk_text_area_get_text ( GTK_TEXT_AREA ( txt));
 		}
 	}
@@ -914,8 +824,7 @@ gchar * gw_categories_edit_box_get_category_description ( GtkWindow *w)
 }
 
 
-gboolean gw_categories_edit_box_get_isadd_state ( GtkWindow *w)
-{
+gboolean gw_categories_edit_box_get_isadd_state ( GtkWindow *w) {
 	GtkButton *bt = NULL;
 	gchar *label = NULL;
 	gchar *text_utf8 = NULL;
@@ -926,17 +835,14 @@ gboolean gw_categories_edit_box_get_isadd_state ( GtkWindow *w)
 		g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-	if ( w != NULL )
-	{
+	if ( w != NULL ) {
 		bt = gtk_object_get_data ( GTK_OBJECT ( w), GW_REF_CATEGORIES_EDIT_BOX_ADD_UPDATE_BUTTON);
 
-		if ( bt != NULL )
-		{
+		if ( bt != NULL ) {
 			gtk_label_get ( GTK_LABEL ( GTK_BIN ( bt)->child), &label);
 			g_strdup_to_gtk_text ( _( "Add"), text_utf8);
 
-			if ( strcmp ( label, text_utf8) == 0 )
-			{
+			if ( strcmp ( label, text_utf8) == 0 ) {
 				result = TRUE;
 			}
 
@@ -948,8 +854,7 @@ gboolean gw_categories_edit_box_get_isadd_state ( GtkWindow *w)
 }
 
 
-gboolean gw_categories_edit_box_get_isupdate_state ( GtkWindow *w)
-{
+gboolean gw_categories_edit_box_get_isupdate_state ( GtkWindow *w) {
 	GtkButton *bt = NULL;
 	gchar *label = NULL;
 	gchar *text_utf8 = NULL;
@@ -960,17 +865,14 @@ gboolean gw_categories_edit_box_get_isupdate_state ( GtkWindow *w)
 	g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-	if ( w != NULL )
-	{
+	if ( w != NULL ) {
 		bt = gtk_object_get_data ( GTK_OBJECT ( w), GW_REF_CATEGORIES_EDIT_BOX_ADD_UPDATE_BUTTON);
 
-		if ( bt != NULL )
-		{
+		if ( bt != NULL ) {
 			gtk_label_get ( GTK_LABEL ( GTK_BIN ( bt)->child), &label);
 			g_strdup_to_gtk_text ( _( "Update"), text_utf8);
 
-			if ( strcmp ( label, text_utf8) == 0 )
-			{
+			if ( strcmp ( label, text_utf8) == 0 ) {
 				result = TRUE;
 			}
 
@@ -982,8 +884,7 @@ gboolean gw_categories_edit_box_get_isupdate_state ( GtkWindow *w)
 }
 
 
-gboolean gw_categories_edit_box_category_name_changed ( GtkWidget *entry, GtkWindow *w)
-{
+gboolean gw_categories_edit_box_category_name_changed ( GtkWidget *entry, GtkWindow *w) {
 	GtkButton *bt = NULL;
 	gboolean result = FALSE;
 	gchar *category_name = NULL;
@@ -993,25 +894,19 @@ gboolean gw_categories_edit_box_category_name_changed ( GtkWidget *entry, GtkWin
 	g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-	if ( w != NULL )
-	{
-		if ( (bt = gw_categories_edit_box_get_add_update_category_button ( w)) != NULL )
-		{
+	if ( w != NULL ) {
+		if ( (bt = gw_categories_edit_box_get_add_update_category_button ( w)) != NULL ) {
 			category_name = gw_categories_edit_box_get_category_name ( w);
 
-			if ( (category_name != NULL) && (strlen ( category_name) > 0) )
-			{
+			if ( (category_name != NULL) && (strlen ( category_name) > 0) ) {
 				gtk_widget_set_sensitive ( GTK_WIDGET ( bt), TRUE);
-			}
-			else
-			{
+			} else {
 				gtk_widget_set_sensitive ( GTK_WIDGET ( bt), FALSE);
 			}
 
-			if ( category_name != NULL )
-			{
+			if ( category_name != NULL ) {
 				g_free ( category_name);
-			}	
+			}
 		}
 	}
 
@@ -1020,8 +915,7 @@ gboolean gw_categories_edit_box_category_name_changed ( GtkWidget *entry, GtkWin
 
 
 
-gboolean gw_categories_edit_box_category_description_changed ( GtkWidget *text, GtkWindow *w)
-{
+gboolean gw_categories_edit_box_category_description_changed ( GtkWidget *text, GtkWindow *w) {
 	GtkButton *bt = NULL;
 	gboolean result = FALSE;
 	gchar *category_name = NULL;
@@ -1031,25 +925,19 @@ gboolean gw_categories_edit_box_category_description_changed ( GtkWidget *text,
 	g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-	if ( w != NULL )
-	{
-		if ( (bt = gw_categories_edit_box_get_add_update_category_button ( w)) != NULL )
-		{
+	if ( w != NULL ) {
+		if ( (bt = gw_categories_edit_box_get_add_update_category_button ( w)) != NULL ) {
 			category_name = gw_categories_edit_box_get_category_name ( w);
 
-			if ( (category_name != NULL) && (strlen ( category_name) > 0) )
-			{
+			if ( (category_name != NULL) && (strlen ( category_name) > 0) ) {
 				gtk_widget_set_sensitive ( GTK_WIDGET ( bt), TRUE);
-			}
-			else
-			{
+			} else {
 				gtk_widget_set_sensitive ( GTK_WIDGET ( bt), FALSE);
 			}
 
-			if ( category_name != NULL )
-			{
+			if ( category_name != NULL ) {
 				g_free ( category_name);
-			}	
+			}
 		}
 	}
 
