@@ -40,6 +40,10 @@
 #define GW_REF_MENU_BAR_FILE_MENU_CLOSE "gw_menu_bar_file_menu_close"
 /*! @define	GW_REF_MENU_BAR_FILE_MENU_SEPARATOR	The file menu -> separator reference */
 #define GW_REF_MENU_BAR_FILE_MENU_SEPARATOR "gw_menu_bar_file_menu_separator"
+/*! @define	GW_REF_MENU_BAR_FILE_MENU_IMPORT	The file menu -> import reference */
+#define GW_REF_MENU_BAR_FILE_MENU_IMPORT "gw_menu_bar_file_menu_import"
+/*! @define	GW_REF_MENU_BAR_FILE_MENU_EXPORT	The file menu -> export reference */
+#define GW_REF_MENU_BAR_FILE_MENU_EXPORT "gw_menu_bar_file_menu_export"
 /*! @define	GW_REF_MENU_BAR_FILE_MENU_PROPERTIES	The file menu -> properties reference */
 #define GW_REF_MENU_BAR_FILE_MENU_PROPERTIES "gw_menu_bar_file_menu_properties"
 /*! @define	GW_REF_MENU_BAR_FILE_MENU_RECENTS_FILES	The file menu -> recents files reference */
@@ -50,8 +54,7 @@
 #define GW_REF_MENU_BAR_FILE_MENU "gw_menu_bar_file_menu"
 
 
-GtkWidget * gw_menu_file_create ( GtkWindow *w, GtkAccelGroup *ag, GtkWidget *parent)
-{
+GtkWidget * gw_menu_file_create ( GtkWindow *w, GtkAccelGroup *ag, GtkWidget *parent) {
 	GtkWidget *gw_menu_file_header = NULL;
 	GtkWidget *menu_file = NULL;
 	GtkWidget *gw_menu_file_new = NULL;
@@ -60,6 +63,10 @@ GtkWidget * gw_menu_file_create ( GtkWindow *w, GtkAccelGroup *ag, GtkWidget *pa
 	GtkWidget *gw_menu_file_saveas = NULL;
 	GtkWidget *gw_menu_file_close = NULL;
 	GtkWidget *gw_menu_file_separator = NULL;
+	GtkWidget *gw_menu_file_import = NULL;
+	GtkWidget *gw_menu_file_import_items = NULL;
+	GtkWidget *gw_menu_file_export = NULL;
+	GtkWidget *gw_menu_file_export_items = NULL;
 	GtkWidget *gw_menu_file_properties = NULL;
 	GtkWidget *gw_menu_file_recents_files = NULL;
 	GtkWidget *gw_menu_file_recents_files_items = NULL;
@@ -171,6 +178,45 @@ GtkWidget * gw_menu_file_create ( GtkWindow *w, GtkAccelGroup *ag, GtkWidget *pa
 	gtk_container_add ( GTK_CONTAINER ( menu_file), gw_menu_file_separator);
 	gtk_widget_set_sensitive ( gw_menu_file_separator, FALSE);
 
+	/* Menu file -> import catalog */
+	gw_menu_file_import = gtk_menu_item_new_with_label ( "");
+	g_strdup_to_gtk_text ( _( "Import"), text_utf8);
+	tmp_key = gtk_label_parse_uline ( GTK_LABEL ( GTK_BIN ( gw_menu_file_import)->child), text_utf8);
+	g_free ( text_utf8);
+#if defined ( HAVE_GTK12)
+	gtk_widget_add_accelerator ( gw_menu_file_import, "activate-item", gw_menu_file_ag, tmp_key, 0, 0);
+#endif
+	gtk_widget_ref ( gw_menu_file_import);
+	gtk_object_set_data_full ( GTK_OBJECT ( w), GW_REF_MENU_BAR_FILE_MENU_IMPORT, gw_menu_file_import, (GtkDestroyNotify) gtk_widget_unref);
+	gtk_container_add ( GTK_CONTAINER ( menu_file), gw_menu_file_import);
+//	gtk_widget_add_accelerator ( gw_menu_file_import, "activate", ag, GDK_m, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
+
+	gw_menu_file_import_items = gtk_menu_new ( );
+	gtk_menu_item_set_submenu ( GTK_MENU_ITEM ( gw_menu_file_import), gw_menu_file_import_items);
+
+	/* Menu file -> export catalog */
+	gw_menu_file_export = gtk_menu_item_new_with_label ( "");
+	g_strdup_to_gtk_text ( _( "Export"), text_utf8);
+	tmp_key = gtk_label_parse_uline ( GTK_LABEL ( GTK_BIN ( gw_menu_file_export)->child), text_utf8);
+	g_free ( text_utf8);
+#if defined ( HAVE_GTK12)
+	gtk_widget_add_accelerator ( gw_menu_file_export, "activate-item", gw_menu_file_ag, tmp_key, 0, 0);
+#endif
+	gtk_widget_ref ( gw_menu_file_export);
+	gtk_object_set_data_full ( GTK_OBJECT ( w), GW_REF_MENU_BAR_FILE_MENU_EXPORT, gw_menu_file_export, (GtkDestroyNotify) gtk_widget_unref);
+	gtk_container_add ( GTK_CONTAINER ( menu_file), gw_menu_file_export);
+//	gtk_widget_add_accelerator ( gw_menu_file_export, "activate", ag, GDK_x, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
+
+	gw_menu_file_export_items = gtk_menu_new ( );
+	gtk_menu_item_set_submenu ( GTK_MENU_ITEM ( gw_menu_file_export), gw_menu_file_export_items);
+
+	/* Menu file -> separator */
+	gw_menu_file_separator = gtk_menu_item_new ( );
+	gtk_widget_ref ( gw_menu_file_separator);
+	gtk_object_set_data_full ( GTK_OBJECT ( w), GW_REF_MENU_BAR_FILE_MENU_SEPARATOR, gw_menu_file_separator, (GtkDestroyNotify) gtk_widget_unref);
+	gtk_container_add ( GTK_CONTAINER ( menu_file), gw_menu_file_separator);
+	gtk_widget_set_sensitive ( gw_menu_file_separator, FALSE);
+
 	/* Menu file -> properties */
 	gw_menu_file_properties = gtk_menu_item_new_with_label ( "");
 	g_strdup_to_gtk_text ( _( "_Properties"), text_utf8);
@@ -233,8 +279,116 @@ GtkWidget * gw_menu_file_create ( GtkWindow *w, GtkAccelGroup *ag, GtkWidget *pa
 }
 
 
-gboolean gw_menu_file_set_recents_files ( GtkWindow *w, gchar **files)
-{
+gboolean gw_menu_file_set_import ( GtkWindow *w, gchar **plugins) {
+	gboolean result = FALSE;
+	GtkMenuItem *import_menu = NULL;
+	GtkWidget *menu_item_import = NULL;
+	GtkWidget *import_submenu = NULL;
+	guint i = 0;
+	gchar *text_utf8 = NULL;
+
+
+#ifdef GW_DEBUG_GUI_COMPONENT
+	g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
+#endif
+
+	if ( (w != NULL) && (plugins != NULL) ) {
+		import_menu = GTK_MENU_ITEM ( gtk_object_get_data ( GTK_OBJECT ( w), GW_REF_MENU_BAR_FILE_MENU_IMPORT));
+
+		if ( import_menu != NULL ) {
+			gtk_menu_item_remove_submenu ( import_menu);
+
+#ifdef GW_DEBUG_GUI_COMPONENT
+			g_print ( "*** GW - %s (%d) :: %s() : Creating a new submenu...\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
+#endif
+
+			import_submenu = gtk_menu_new ( );
+			gtk_menu_item_set_submenu ( import_menu, import_submenu);
+
+			for ( i = 0; plugins[i] != NULL; i++) {
+#ifdef GW_DEBUG_GUI_COMPONENT
+				g_print ( "*** GW - %s (%d) :: %s() : Creating a new submenu item at %d\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, i);
+				g_print ( "*** GW - %s (%d) :: %s() : Creating a new submenu item => %s\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, plugins[i]);
+#endif
+
+				g_strdup_to_gtk_text ( plugins[i], text_utf8);
+				menu_item_import = gtk_menu_item_new_with_label ( text_utf8);
+				g_free ( text_utf8);
+				gtk_container_add ( GTK_CONTAINER ( import_submenu), menu_item_import);
+
+				gtk_signal_connect ( GTK_OBJECT ( menu_item_import), "activate", GTK_SIGNAL_FUNC ( gw_menu_file_import_item_click), plugins[i]);
+			}
+
+			gtk_widget_show_all ( GTK_WIDGET ( import_menu));
+
+			result = TRUE;
+		}
+
+#ifdef GW_DEBUG_GUI_COMPONENT
+	g_print ( "*** GW - %s (%d) :: %s() : import plugins are added.\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
+#endif
+	}
+
+	return result;
+}
+
+
+gboolean gw_menu_file_set_export ( GtkWindow *w, gchar **plugins) {
+	gboolean result = FALSE;
+	GtkMenuItem *import_menu = NULL;
+	GtkWidget *menu_item_import = NULL;
+	GtkWidget *import_submenu = NULL;
+	guint i = 0;
+	gchar *text_utf8 = NULL;
+
+
+#ifdef GW_DEBUG_GUI_COMPONENT
+	g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
+#endif
+
+	if ( (w != NULL) && (plugins != NULL) ) {
+		import_menu = GTK_MENU_ITEM ( gtk_object_get_data ( GTK_OBJECT ( w), GW_REF_MENU_BAR_FILE_MENU_EXPORT));
+
+		if ( import_menu != NULL ) {
+			gtk_menu_item_remove_submenu ( import_menu);
+
+#ifdef GW_DEBUG_GUI_COMPONENT
+			g_print ( "*** GW - %s (%d) :: %s() : Creating a new submenu...\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
+#endif
+
+			import_submenu = gtk_menu_new ( );
+			gtk_menu_item_set_submenu ( import_menu, import_submenu);
+
+			for ( i = 0; plugins[i] != NULL; i++) {
+#ifdef GW_DEBUG_GUI_COMPONENT
+				g_print ( "*** GW - %s (%d) :: %s() : Creating a new submenu item at %d\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, i);
+				g_print ( "*** GW - %s (%d) :: %s() : Creating a new submenu item => %s\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, plugins[i]);
+#endif
+
+				g_strdup_to_gtk_text ( plugins[i], text_utf8);
+				menu_item_import = gtk_menu_item_new_with_label ( text_utf8);
+				g_free ( text_utf8);
+				gtk_container_add ( GTK_CONTAINER ( import_submenu), menu_item_import);
+
+				/* Warning use a gint value instead of a gpointer value!! */
+				gtk_signal_connect ( GTK_OBJECT ( menu_item_import), "activate", GTK_SIGNAL_FUNC ( gw_menu_file_export_item_click), /*GUINT_TO_POINTER ( i)*/g_strdup ( plugins[i]));
+			}
+
+			gtk_widget_show_all ( GTK_WIDGET ( import_menu));
+
+			result = TRUE;
+		}
+
+#ifdef GW_DEBUG_GUI_COMPONENT
+	g_print ( "*** GW - %s (%d) :: %s() : export plugins are added.\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
+#endif
+	}
+
+	return result;
+}
+
+
+gboolean gw_menu_file_set_recents_files ( GtkWindow *w, gchar **files) {
 	gboolean result = FALSE;
 	GtkMenuItem *recents_files_menu = NULL;
 	GtkWidget *menu_item_recents_files = NULL;
@@ -247,12 +401,10 @@ gboolean gw_menu_file_set_recents_files ( GtkWindow *w, gchar **files)
 	g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-	if ( (w != NULL) && (files != NULL) )
-	{
+	if ( (w != NULL) && (files != NULL) ) {
 		recents_files_menu = GTK_MENU_ITEM ( gtk_object_get_data ( GTK_OBJECT ( w), GW_REF_MENU_BAR_FILE_MENU_RECENTS_FILES));
 
-		if ( recents_files_menu != NULL )
-		{
+		if ( recents_files_menu != NULL ) {
 			gtk_menu_item_remove_submenu ( recents_files_menu);
 
 #ifdef GW_DEBUG_GUI_COMPONENT
@@ -262,8 +414,7 @@ gboolean gw_menu_file_set_recents_files ( GtkWindow *w, gchar **files)
 			recents_files_submenu = gtk_menu_new ( );
 			gtk_menu_item_set_submenu ( recents_files_menu, recents_files_submenu);
 
-			for ( i = 0; files[i] != NULL; i++)
-			{
+			for ( i = 0; files[i] != NULL; i++) {
 #ifdef GW_DEBUG_GUI_COMPONENT
 				g_print ( "*** GW - %s (%d) :: %s() : Creating a new submenu item at %d\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, i);
 				g_print ( "*** GW - %s (%d) :: %s() : Creating a new submenu item => %s\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, files[i]);
