@@ -45,8 +45,7 @@
 #define GW_REF_NOTEBOOK_CATALOG_TABBED_PANE_LABEL "gw_ref_gw_notebook_catalog_tabbed_pane_label"
 
 
-GtkWidget * gw_notebook_catalog_create ( GtkWindow * window)
-{
+GtkWidget * gw_notebook_catalog_create ( GtkWindow * window) {
 	GtkCList *clist_info = NULL;
 	GtkWidget *hpan_catalog;
 	GtkWidget *lbl_archive;
@@ -66,8 +65,7 @@ GtkWidget * gw_notebook_catalog_create ( GtkWindow * window)
 	gtk_widget_ref ( hpan_catalog);
 	gtk_object_set_data_full ( GTK_OBJECT ( window), GW_REF_NOTEBOOK_CATALOG_PANE, hpan_catalog, (GtkDestroyNotify) gtk_widget_unref);
 	/* Gets the saved value of the horizontal pane position. */
-	if ( (hpan_pos = gw_application_manager_get_settings_tod ( GW_VALUE_APP_EXPLORER_HPAN_POSITION)) == -1 )
-	{
+	if ( (hpan_pos = gw_am_get_settings_tod ( GW_VALUE_APP_EXPLORER_HPAN_POSITION)) == -1 ) {
 		hpan_pos = GW_VALUE_APP_EXPLORER_HPAN_POSITION_DEFAULT;
 	}
 	gtk_paned_set_position ( GTK_PANED ( hpan_catalog), hpan_pos);
@@ -134,6 +132,7 @@ GtkWidget * gw_notebook_catalog_create ( GtkWindow * window)
 	gtk_clist_set_column_justification ( clist_info, 10, GTK_JUSTIFY_LEFT);
 	gtk_clist_set_column_justification ( clist_info, 11, GTK_JUSTIFY_LEFT);
 */
+
 	gtk_clist_set_sort_column ( clist_info, 0);
 	gtk_clist_set_sort_type ( clist_info, GTK_SORT_ASCENDING);
 	gtk_clist_set_auto_sort ( clist_info, FALSE);
@@ -183,8 +182,7 @@ GtkWidget * gw_notebook_catalog_create ( GtkWindow * window)
 }
 
 
-GtkWidget * gw_notebook_catalog_create_and_add ( GtkWindow * window, GtkNotebook * parent)
-{
+GtkWidget * gw_notebook_catalog_create_and_add ( GtkWindow * window, GtkNotebook * parent) {
 	GtkWidget *tabbed_pane_catalog = NULL;
 	GtkWidget *catalog_tabbed_pane_label;
 	gchar *text_utf8 = NULL;
@@ -194,12 +192,10 @@ GtkWidget * gw_notebook_catalog_create_and_add ( GtkWindow * window, GtkNotebook
 	g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-	if ( window != NULL )
-	{
+	if ( window != NULL ) {
 		tabbed_pane_catalog = gw_notebook_catalog_create ( window);
 
-		if ( tabbed_pane_catalog != NULL )
-		{
+		if ( tabbed_pane_catalog != NULL ) {
 			gtk_container_add ( GTK_CONTAINER ( parent), tabbed_pane_catalog);
 
 			/* Text label of the search tabbed pane. */
@@ -218,8 +214,7 @@ GtkWidget * gw_notebook_catalog_create_and_add ( GtkWindow * window, GtkNotebook
 }
 
 
-GtkCList * gw_notebook_catalog_get_clist_explorer ( GtkWindow *w)
-{
+GtkCList * gw_notebook_catalog_get_clist_explorer ( GtkWindow *w) {
 	GtkCList *clist_explorer = NULL;
 
 
@@ -227,8 +222,7 @@ GtkCList * gw_notebook_catalog_get_clist_explorer ( GtkWindow *w)
 	g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-	if ( w != NULL )
-	{
+	if ( w != NULL ) {
 		clist_explorer = GTK_CLIST ( gtk_object_get_data ( GTK_OBJECT ( w), GW_REF_CLIST_EXPLORER));
 	}
 
@@ -236,8 +230,7 @@ GtkCList * gw_notebook_catalog_get_clist_explorer ( GtkWindow *w)
 }
 
 
-gint gw_notebook_catalog_clist_explorer_set_column_title_file ( void)
-{
+gint gw_notebook_catalog_clist_explorer_set_column_title_file ( void) {
 	GtkWindow *w = NULL;
 	GtkCList *clist = NULL;
 	gchar *showed = NULL;
@@ -254,105 +247,88 @@ gint gw_notebook_catalog_clist_explorer_set_column_title_file ( void)
 	w = gw_gui_manager_main_interface_get_main_window ( );
 	clist = gw_notebook_catalog_get_clist_explorer ( w);
 
-	if ( clist != NULL )
-	{
+	if ( clist != NULL ) {
 		gtk_clist_freeze ( clist);
 //		gtk_signal_emit_stop_by_name ( GTK_OBJECT ( clist), "resize-column");
 
 		/* Sets columns width. */
-		if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_NAME_SIZE)) == -1 )
-		{
+		if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_NAME_SIZE)) == -1 ) {
 			width = GW_VALUE_APP_EXPLORER_FILE_COLUMN_NAME_SIZE_DEFAULT;
 		}
 
 		gtk_clist_set_column_width ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_NAME_POSITION_DEFAULT, width);
 
-		if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_RIGHTS_SIZE)) == -1 )
-		{
+		if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_RIGHTS_SIZE)) == -1 ) {
 			width = GW_VALUE_APP_EXPLORER_FILE_COLUMN_RIGHTS_SIZE_DEFAULT;
 		}
 
 		gtk_clist_set_column_width ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_RIGHTS_POSITION_DEFAULT, width);
 
-		if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_OWNER_SIZE)) == -1 )
-		{
+		if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_OWNER_SIZE)) == -1 ) {
 			width = GW_VALUE_APP_EXPLORER_FILE_COLUMN_OWNER_SIZE_DEFAULT;
 		}
 
 		gtk_clist_set_column_width ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_OWNER_POSITION_DEFAULT, width);
 
-		if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_GROUP_SIZE)) == -1 )
-		{
+		if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_GROUP_SIZE)) == -1 ) {
 			width = GW_VALUE_APP_EXPLORER_FILE_COLUMN_GROUP_SIZE_DEFAULT;
 		}
 
 		gtk_clist_set_column_width ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_GROUP_POSITION_DEFAULT, width);
 
-		if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_SIZE_SIZE)) == -1 )
-		{
+		if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_SIZE_SIZE)) == -1 ) {
 			width = GW_VALUE_APP_EXPLORER_FILE_COLUMN_SIZE_SIZE_DEFAULT;
 		}
 
 		gtk_clist_set_column_width ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_SIZE_POSITION_DEFAULT, width);
 
-		if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_INODE_SIZE)) == -1 )
-		{
+		if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_INODE_SIZE)) == -1 ) {
 			width = GW_VALUE_APP_EXPLORER_FILE_COLUMN_INODE_SIZE_DEFAULT;
 		}
 
 		gtk_clist_set_column_width ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_INODE_POSITION_DEFAULT, width);
 
-		if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_CDATE_SIZE)) == -1 )
-		{
+		if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_CDATE_SIZE)) == -1 ) {
 			width = GW_VALUE_APP_EXPLORER_FILE_COLUMN_CDATE_SIZE_DEFAULT;
 		}
 
 		gtk_clist_set_column_width ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_CDATE_POSITION_DEFAULT, width);
 
-		if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_MDATE_SIZE)) == -1 )
-		{
+		if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_MDATE_SIZE)) == -1 ) {
 			width = GW_VALUE_APP_EXPLORER_FILE_COLUMN_MDATE_SIZE_DEFAULT;
 		}
 
 		gtk_clist_set_column_width ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_MDATE_POSITION_DEFAULT, width);
 
-		if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_ADATE_SIZE)) == -1 )
-		{
+		if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_ADATE_SIZE)) == -1 ) {
 			width = GW_VALUE_APP_EXPLORER_FILE_COLUMN_ADATE_SIZE_DEFAULT;
 		}
 
 		gtk_clist_set_column_width ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_ADATE_POSITION_DEFAULT, width);
 
-		if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_CATEGORY_SIZE)) == -1 )
-		{
+		if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_CATEGORY_SIZE)) == -1 ) {
 			width = GW_VALUE_APP_EXPLORER_FILE_COLUMN_CATEGORY_SIZE_DEFAULT;
 		}
 
 		gtk_clist_set_column_width ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_DESCRIPTION_POSITION_DEFAULT, width);
 
-		if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_DESCRIPTION_SIZE)) == -1 )
-		{
+		if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_DESCRIPTION_SIZE)) == -1 ) {
 			width = GW_VALUE_APP_EXPLORER_FILE_COLUMN_DESCRIPTION_SIZE_DEFAULT;
 		}
 
 		gtk_clist_set_column_width ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_CATEGORY_POSITION_DEFAULT, width);
 
-		if ( (autoresize = gw_application_manager_get_settings_tol ( GW_VALUE_APP_EXPLORER_COLUMN_AUTORESIZE)) == -1 )
-		{
+		if ( (autoresize = gw_am_get_settings_tol ( GW_VALUE_APP_EXPLORER_COLUMN_AUTORESIZE)) == -1 ) {
 			autoresize = GW_VALUE_APP_EXPLORER_COLUMN_AUTORESIZE_DEFAULT;
 		}
 
 		/* Sets the autoresize mode. */
-		for ( i = 0; i < 11; i++)
-		{
+		for ( i = 0; i < 11; i++) {
 			/* Enabling auto-resize on a column disallows user-resizing of the column. */
-			if ( autoresize )
-			{
+			if ( autoresize ) {
 				gtk_clist_set_column_resizeable ( clist, i, FALSE);
 				gtk_clist_set_column_auto_resize ( clist, i, TRUE);
-			}
-			else
-			{
+			} else {
 				gtk_clist_set_column_auto_resize ( clist, i, FALSE);
 				gtk_clist_set_column_resizeable ( clist, i, TRUE);
 			}
@@ -393,102 +369,69 @@ gint gw_notebook_catalog_clist_explorer_set_column_title_file ( void)
 		gtk_clist_set_column_title ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_DESCRIPTION_POSITION_DEFAULT, text_utf8);
 		g_free ( text_utf8);
 
-		if ( ((showed = gw_application_manager_get_settings ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_NAME_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
-		{
+		if ( ((showed = gw_am_get_settings ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_NAME_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) ) {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_NAME_POSITION_DEFAULT, FALSE);
-		}
-		else
-		{
+		} else {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_NAME_POSITION_DEFAULT, TRUE);
 		}
 
-		if ( ((showed = gw_application_manager_get_settings ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_RIGHTS_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
-		{
+		if ( ((showed = gw_am_get_settings ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_RIGHTS_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) ) {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_RIGHTS_POSITION_DEFAULT, FALSE);
-		}
-		else
-		{
+		} else {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_RIGHTS_POSITION_DEFAULT, TRUE);
 		}
 
-		if ( ((showed = gw_application_manager_get_settings ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_OWNER_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
-		{
+		if ( ((showed = gw_am_get_settings ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_OWNER_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) ) {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_OWNER_POSITION_DEFAULT, FALSE);
-		}
-		else
-		{
+		} else {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_OWNER_POSITION_DEFAULT, TRUE);
 		}
 
-		if ( ((showed = gw_application_manager_get_settings ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_GROUP_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
-		{
+		if ( ((showed = gw_am_get_settings ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_GROUP_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) ) {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_GROUP_POSITION_DEFAULT, FALSE);
-		}
-		else
-		{
+		} else {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_GROUP_POSITION_DEFAULT, TRUE);
 		}
 
-		if ( ((showed = gw_application_manager_get_settings ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_SIZE_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
-		{
+		if ( ((showed = gw_am_get_settings ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_SIZE_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) ) {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_SIZE_POSITION_DEFAULT, FALSE);
-		}
-		else
-		{
+		} else {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_SIZE_POSITION_DEFAULT, TRUE);
 		}
 
-		if ( ((showed = gw_application_manager_get_settings ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_INODE_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
-		{
+		if ( ((showed = gw_am_get_settings ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_INODE_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) ) {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_INODE_POSITION_DEFAULT, FALSE);
-		}
-		else
-		{
+		} else {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_INODE_POSITION_DEFAULT, TRUE);
 		}
 
-		if ( ((showed = gw_application_manager_get_settings ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_CDATE_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
-		{
+		if ( ((showed = gw_am_get_settings ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_CDATE_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) ) {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_CDATE_POSITION_DEFAULT, FALSE);
-		}
-		else
-		{
+		} else {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_CDATE_POSITION_DEFAULT, TRUE);
 		}
 
-		if ( ((showed = gw_application_manager_get_settings ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_MDATE_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
-		{
+		if ( ((showed = gw_am_get_settings ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_MDATE_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) ) {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_MDATE_POSITION_DEFAULT, FALSE);
-		}
-		else
-		{
+		} else {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_MDATE_POSITION_DEFAULT, TRUE);
 		}
 
-		if ( ((showed = gw_application_manager_get_settings ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_ADATE_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
-		{
+		if ( ((showed = gw_am_get_settings ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_ADATE_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) ) {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_ADATE_POSITION_DEFAULT, FALSE);
-		}
-		else
-		{
+		} else {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_ADATE_POSITION_DEFAULT, TRUE);
 		}
 
-		if ( ((showed = gw_application_manager_get_settings ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_CATEGORY_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
-		{
+		if ( ((showed = gw_am_get_settings ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_CATEGORY_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) ) {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_CATEGORY_POSITION_DEFAULT, FALSE);
-		}
-		else
-		{
+		} else {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_CATEGORY_POSITION_DEFAULT, TRUE);
 		}
 
-		if ( ((showed = gw_application_manager_get_settings ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_DESCRIPTION_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
-		{
+		if ( ((showed = gw_am_get_settings ( GW_VALUE_APP_EXPLORER_FILE_COLUMN_DESCRIPTION_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) ) {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_DESCRIPTION_POSITION_DEFAULT, FALSE);
-		}
-		else
-		{
+		} else {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_FILE_COLUMN_DESCRIPTION_POSITION_DEFAULT, TRUE);
 		}
 
@@ -506,8 +449,7 @@ gint gw_notebook_catalog_clist_explorer_set_column_title_file ( void)
 }
 
 
-gint gw_notebook_catalog_clist_explorer_set_column_title_disk ( void)
-{
+gint gw_notebook_catalog_clist_explorer_set_column_title_disk ( void) {
 	GtkWindow *w = NULL;
 	GtkCList *clist = NULL;
 	gchar *showed = NULL;
@@ -524,112 +466,94 @@ gint gw_notebook_catalog_clist_explorer_set_column_title_disk ( void)
 	w = gw_gui_manager_main_interface_get_main_window ( );
 	clist = gw_notebook_catalog_get_clist_explorer ( w);
 
-	if ( clist != NULL )
-	{
+	if ( clist != NULL ) {
 		gtk_clist_freeze ( clist);
 //		gtk_signal_emit_stop_by_name ( GTK_OBJECT ( clist), "resize-column");
 
 		/* Sets columns width. */
-		if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_NAME_SIZE)) == -1 )
-		{
+		if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_NAME_SIZE)) == -1 ) {
 			width = GW_VALUE_APP_EXPLORER_DISK_COLUMN_NAME_SIZE_DEFAULT;
 		}
 
 		gtk_clist_set_column_width ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_NAME_POSITION_DEFAULT, width);
 
-		if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_FSNAME_SIZE)) == -1 )
-		{
+		if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_FSNAME_SIZE)) == -1 ) {
 			width = GW_VALUE_APP_EXPLORER_DISK_COLUMN_FSNAME_SIZE_DEFAULT;
 		}
 
 		gtk_clist_set_column_width ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_FSNAME_POSITION_DEFAULT, width);
 
-		if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_PATH_SIZE)) == -1 )
-		{
+		if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_PATH_SIZE)) == -1 ) {
 			width = GW_VALUE_APP_EXPLORER_DISK_COLUMN_PATH_SIZE_DEFAULT;
 		}
 
 		gtk_clist_set_column_width ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_PATH_POSITION_DEFAULT, width);
 
-		if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_NBARCHIVE_SIZE)) == -1 )
-		{
+		if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_NBARCHIVE_SIZE)) == -1 ) {
 			width = GW_VALUE_APP_EXPLORER_DISK_COLUMN_NBARCHIVE_SIZE_DEFAULT;
 		}
 
 		gtk_clist_set_column_width ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_NBARCHIVE_POSITION_DEFAULT, width);
 
-		if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_TYPE_SIZE)) == -1 )
-		{
+		if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_TYPE_SIZE)) == -1 ) {
 			width = GW_VALUE_APP_EXPLORER_DISK_COLUMN_TYPE_SIZE_DEFAULT;
 		}
 
 		gtk_clist_set_column_width ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_TYPE_POSITION_DEFAULT, width);
 
-		if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_VOLUME_SIZE)) == -1 )
-		{
+		if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_VOLUME_SIZE)) == -1 ) {
 			width = GW_VALUE_APP_EXPLORER_DISK_COLUMN_VOLUME_SIZE_DEFAULT;
 		}
 
 		gtk_clist_set_column_width ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_VOLUME_POSITION_DEFAULT, width);
 
-		if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_CAPACITY_SIZE)) == -1 )
-		{
+		if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_CAPACITY_SIZE)) == -1 ) {
 			width = GW_VALUE_APP_EXPLORER_DISK_COLUMN_CAPACITY_SIZE_DEFAULT;
 		}
 
 		gtk_clist_set_column_width ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_CAPACITY_POSITION_DEFAULT, width);
 
-		if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_FREE_SIZE)) == -1 )
-		{
+		if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_FREE_SIZE)) == -1 ) {
 			width = GW_VALUE_APP_EXPLORER_DISK_COLUMN_FREE_SIZE_DEFAULT;
 		}
 
 		gtk_clist_set_column_width ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_FREE_POSITION_DEFAULT, width);
 
-		if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_DATE_SIZE)) == -1 )
-		{
+		if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_DATE_SIZE)) == -1 ) {
 			width = GW_VALUE_APP_EXPLORER_DISK_COLUMN_DATE_SIZE_DEFAULT;
 		}
 
 		gtk_clist_set_column_width ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_DATE_POSITION_DEFAULT, width);
 
-		if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_SERIAL_SIZE)) == -1 )
-		{
+		if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_SERIAL_SIZE)) == -1 ) {
 			width = GW_VALUE_APP_EXPLORER_DISK_COLUMN_SERIAL_SIZE_DEFAULT;
 		}
 
 		gtk_clist_set_column_width ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_SERIAL_POSITION_DEFAULT, width);
 
-		if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_CATEGORY_SIZE)) == -1 )
-		{
+		if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_CATEGORY_SIZE)) == -1 ) {
 			width = GW_VALUE_APP_EXPLORER_DISK_COLUMN_CATEGORY_SIZE_DEFAULT;
 		}
 
 		gtk_clist_set_column_width ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_CATEGORY_POSITION_DEFAULT, width);
 
-		if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_DESCRIPTION_SIZE)) == -1 )
-		{
+		if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_DESCRIPTION_SIZE)) == -1 ) {
 			width = GW_VALUE_APP_EXPLORER_DISK_COLUMN_DESCRIPTION_SIZE_DEFAULT;
 		}
 
 		gtk_clist_set_column_width ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_DESCRIPTION_POSITION_DEFAULT, width);
 
-		if ( (autoresize = gw_application_manager_get_settings_tol ( GW_VALUE_APP_EXPLORER_COLUMN_AUTORESIZE)) == -1 )
-		{
+		if ( (autoresize = gw_am_get_settings_tol ( GW_VALUE_APP_EXPLORER_COLUMN_AUTORESIZE)) == -1 ) {
 			autoresize = GW_VALUE_APP_EXPLORER_COLUMN_AUTORESIZE_DEFAULT;
 		}
 
 		/* Sets the autoresize mode. */
-		for ( i = 0; i < 11; i++)
-		{
+		for ( i = 0; i < 11; i++) {
 			/* Enabling auto-resize on a column disallows user-resizing of the column. */
-			if ( autoresize )
-			{
+			if ( autoresize ) {
 				gtk_clist_set_column_resizeable ( clist, i, FALSE);
 				gtk_clist_set_column_auto_resize ( clist, i, TRUE);
-			}
-			else
-			{
+			} else {
 				gtk_clist_set_column_auto_resize ( clist, i, FALSE);
 				gtk_clist_set_column_resizeable ( clist, i, TRUE);
 			}
@@ -673,111 +597,75 @@ gint gw_notebook_catalog_clist_explorer_set_column_title_disk ( void)
 		gtk_clist_set_column_title ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_DESCRIPTION_POSITION_DEFAULT, text_utf8);
 		g_free ( text_utf8);
 
-		if ( ((showed = gw_application_manager_get_settings ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_NAME_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
-		{
+		if ( ((showed = gw_am_get_settings ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_NAME_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) ) {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_NAME_POSITION_DEFAULT, FALSE);
-		}
-		else
-		{
+		} else {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_NAME_POSITION_DEFAULT, TRUE);
 		}
 
-		if ( ((showed = gw_application_manager_get_settings ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_FSNAME_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
-		{
+		if ( ((showed = gw_am_get_settings ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_FSNAME_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) ) {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_FSNAME_POSITION_DEFAULT, FALSE);
-		}
-		else
-		{
+		} else {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_FSNAME_POSITION_DEFAULT, TRUE);
 		}
 
-		if ( ((showed = gw_application_manager_get_settings ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_PATH_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
-		{
+		if ( ((showed = gw_am_get_settings ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_PATH_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) ) {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_PATH_POSITION_DEFAULT, FALSE);
-		}
-		else
-		{
+		} else {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_PATH_POSITION_DEFAULT, TRUE);
 		}
 
-		if ( ((showed = gw_application_manager_get_settings ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_NBARCHIVE_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
-		{
+		if ( ((showed = gw_am_get_settings ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_NBARCHIVE_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) ) {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_NBARCHIVE_POSITION_DEFAULT, FALSE);
-		}
-		else
-		{
+		} else {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_NBARCHIVE_POSITION_DEFAULT, TRUE);
 		}
 
-		if ( ((showed = gw_application_manager_get_settings ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_TYPE_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
-		{
+		if ( ((showed = gw_am_get_settings ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_TYPE_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) ) {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_TYPE_POSITION_DEFAULT, FALSE);
-		}
-		else
-		{
+		} else {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_TYPE_POSITION_DEFAULT, TRUE);
 		}
 
-		if ( ((showed = gw_application_manager_get_settings ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_VOLUME_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
-		{
+		if ( ((showed = gw_am_get_settings ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_VOLUME_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) ) {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_VOLUME_POSITION_DEFAULT, FALSE);
-		}
-		else
-		{
+		} else {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_VOLUME_POSITION_DEFAULT, TRUE);
 		}
 
-		if ( ((showed = gw_application_manager_get_settings ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_CAPACITY_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
-		{
+		if ( ((showed = gw_am_get_settings ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_CAPACITY_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) ) {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_CAPACITY_POSITION_DEFAULT, FALSE);
-		}
-		else
-		{
+		} else {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_CAPACITY_POSITION_DEFAULT, TRUE);
 		}
 
-		if ( ((showed = gw_application_manager_get_settings ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_FREE_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
-		{
+		if ( ((showed = gw_am_get_settings ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_FREE_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) ) {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_FREE_POSITION_DEFAULT, FALSE);
-		}
-		else
-		{
+		} else {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_FREE_POSITION_DEFAULT, TRUE);
 		}
 
-		if ( ((showed = gw_application_manager_get_settings ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_DATE_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
-		{
+		if ( ((showed = gw_am_get_settings ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_DATE_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) ) {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_DATE_POSITION_DEFAULT, FALSE);
-		}
-		else
-		{
+		} else {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_DATE_POSITION_DEFAULT, TRUE);
 		}
 
-		if ( ((showed = gw_application_manager_get_settings ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_SERIAL_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
-		{
+		if ( ((showed = gw_am_get_settings ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_SERIAL_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) ) {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_SERIAL_POSITION_DEFAULT, FALSE);
-		}
-		else
-		{
+		} else {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_SERIAL_POSITION_DEFAULT, TRUE);
 		}
 
-		if ( ((showed = gw_application_manager_get_settings ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_CATEGORY_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
-		{
+		if ( ((showed = gw_am_get_settings ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_CATEGORY_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) ) {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_CATEGORY_POSITION_DEFAULT, FALSE);
-		}
-		else
-		{
+		} else {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_CATEGORY_POSITION_DEFAULT, TRUE);
 		}
 
-		if ( ((showed = gw_application_manager_get_settings ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_DESCRIPTION_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
-		{
+		if ( ((showed = gw_am_get_settings ( GW_VALUE_APP_EXPLORER_DISK_COLUMN_DESCRIPTION_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) ) {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_DESCRIPTION_POSITION_DEFAULT, FALSE);
-		}
-		else
-		{
+		} else {
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_EXPLORER_DISK_COLUMN_DESCRIPTION_POSITION_DEFAULT, TRUE);
 		}
 
@@ -792,8 +680,7 @@ gint gw_notebook_catalog_clist_explorer_set_column_title_disk ( void)
 }
 
 
-GtkCTreeNode * gw_notebook_catalog_ctree_node_get_child  ( GtkCTreeNode *node, gchar *name)
-{
+GtkCTreeNode * gw_notebook_catalog_ctree_node_get_child  ( GtkCTreeNode *node, gchar *name) {
 	GtkCTreeNode *child = NULL;
 	gchar *txt;
 	guint8 spc;
@@ -807,19 +694,15 @@ GtkCTreeNode * gw_notebook_catalog_ctree_node_get_child  ( GtkCTreeNode *node, g
 	g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-	if ( node != NULL )
-	{
+	if ( node != NULL ) {
 		child = GTK_CTREE_ROW ( node)->children;
 		ctree = gw_gui_manager_main_interface_get_tree ( );
 
-		while ( child != NULL )
-		{
-			if ( gtk_ctree_node_get_pixtext ( GTK_CTREE ( ctree), child, 0, &txt, &spc, &pxmp, &btmp) )
-			{
+		while ( child != NULL ) {
+			if ( gtk_ctree_node_get_pixtext ( GTK_CTREE ( ctree), child, 0, &txt, &spc, &pxmp, &btmp) ) {
 				g_strdup_from_gtk_text ( txt, text_utf8);
 
-				if ( strcmp ( text_utf8, name) == 0 )
-				{
+				if ( strcmp ( text_utf8, name) == 0 ) {
 					g_free ( text_utf8);
 
 					return child;
@@ -836,8 +719,7 @@ GtkCTreeNode * gw_notebook_catalog_ctree_node_get_child  ( GtkCTreeNode *node, g
 }
 
 
-gint gw_notebook_catalog_ctree_node_get_num_children ( GtkCTreeNode *node)
-{
+gint gw_notebook_catalog_ctree_node_get_num_children ( GtkCTreeNode *node) {
 	GtkCTreeNode *child = NULL;
 	gint n = 0;
 
@@ -846,12 +728,10 @@ gint gw_notebook_catalog_ctree_node_get_num_children ( GtkCTreeNode *node)
 	g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-	if ( node != NULL )
-	{
+	if ( node != NULL ) {
 		child = GTK_CTREE_ROW ( node)->children;
 
-		while ( child != NULL )
-		{
+		while ( child != NULL ) {
 			n++;
 			child = GTK_CTREE_ROW ( child)->sibling;
 		}
@@ -861,8 +741,7 @@ gint gw_notebook_catalog_ctree_node_get_num_children ( GtkCTreeNode *node)
 }
 
 
-gint gw_notebook_catalog_ctree_destroy_all ( void)
-{
+gint gw_notebook_catalog_ctree_destroy_all ( void) {
 	/* Destroys all explorer tree :'( */
 	GtkWindow *w = NULL;
 	GtkCList *clist_info = NULL;
@@ -877,13 +756,11 @@ gint gw_notebook_catalog_ctree_destroy_all ( void)
 	g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-	if ( (w = gw_gui_manager_main_interface_get_main_window ( )) != NULL )
-	{
+	if ( (w = gw_gui_manager_main_interface_get_main_window ( )) != NULL ) {
 		clist_info = gw_notebook_catalog_get_clist_explorer ( w);
 		clist_result = gw_notebook_search_get_clist_search ( w);
 		ctree = gw_gui_manager_main_interface_get_tree ( );
 		root = gw_gui_manager_main_interface_get_tree_root ( );
-
 		gw_status_bar_put_messages ( w, _( "Closing catalog"), _( "Please wait..."));
 		gw_gui_manager_main_interface_refresh ( );
 
@@ -910,7 +787,7 @@ gint gw_notebook_catalog_ctree_destroy_all ( void)
 	}
 
 #ifdef GW_DEBUG_MODE
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "application is exited ==> memory status : ");
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "application is exited ==> memory status : ");
 	g_mem_profile ( );
 #endif
 
@@ -918,8 +795,7 @@ gint gw_notebook_catalog_ctree_destroy_all ( void)
 }
 
 
-gint gw_notebook_catalog_get_hpan_position ( GtkWindow *w)
-{
+gint gw_notebook_catalog_get_hpan_position ( GtkWindow *w) {
 	gint position = -1;
 	GtkPaned *hpan = NULL;
 
@@ -928,10 +804,8 @@ gint gw_notebook_catalog_get_hpan_position ( GtkWindow *w)
 	g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-	if ( w != NULL )
-	{
-		if ( (hpan = GTK_PANED ( gtk_object_get_data ( GTK_OBJECT ( w), GW_REF_NOTEBOOK_CATALOG_PANE))) != NULL)
-		{
+	if ( w != NULL ) {
+		if ( (hpan = GTK_PANED ( gtk_object_get_data ( GTK_OBJECT ( w), GW_REF_NOTEBOOK_CATALOG_PANE))) != NULL) {
 #ifdef HAVE_GTK20
 			position = gtk_paned_get_position ( hpan);
 #elif defined HAVE_GTK12
