@@ -528,9 +528,9 @@ GtkWidget * gw_notebook_managment_create ( GtkWindow * window)
 		gw_combo_box_categories_load ( cmb_categories);
 
 		/* Fills the pattern to use for disk name */
-		if ( gw_application_manager_get_settings_tol ( GW_VALUE_APP_DISK_SCAN_USE_PATTERN) == 1)
+		if ( gw_am_get_settings_tol ( GW_VALUE_APP_DISK_SCAN_USE_PATTERN) == 1)
 		{
-			gw_notebook_managment_set_device_name ( window, gw_application_manager_get_settings ( GW_VALUE_APP_DISK_SCAN_PATTERN));
+			gw_notebook_managment_set_device_name ( window, gw_am_get_settings ( GW_VALUE_APP_DISK_SCAN_PATTERN));
 		}
 	}
 
