@@ -1019,49 +1019,49 @@ gint gw_notebook_search_clist_search_set_column_title ( void)
 	if ( clist != NULL )
 	{
 		/* Sets columns width. */
-		if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_SEARCH_COLUMN_NAME_SIZE)) == -1 )
+		if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_SEARCH_COLUMN_NAME_SIZE)) == -1 )
 		{
 			width = GW_VALUE_APP_SEARCH_COLUMN_NAME_SIZE_DEFAULT;
 		}
 
 		gtk_clist_set_column_width ( clist, GW_VALUE_APP_SEARCH_COLUMN_NAME_POSITION_DEFAULT, width);
 
-		if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_SEARCH_COLUMN_DISK_SIZE)) == -1 )
+		if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_SEARCH_COLUMN_DISK_SIZE)) == -1 )
 		{
 			width = GW_VALUE_APP_SEARCH_COLUMN_DISK_SIZE_DEFAULT;
 		}
 
 		gtk_clist_set_column_width ( clist, GW_VALUE_APP_SEARCH_COLUMN_DISK_POSITION_DEFAULT, width);
 
-		if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_SEARCH_COLUMN_PATH_SIZE)) == -1 )
+		if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_SEARCH_COLUMN_PATH_SIZE)) == -1 )
 		{
 			width = GW_VALUE_APP_SEARCH_COLUMN_PATH_SIZE_DEFAULT;
 		}
 
 		gtk_clist_set_column_width ( clist, GW_VALUE_APP_SEARCH_COLUMN_PATH_POSITION_DEFAULT, width);
 
-		if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_SEARCH_COLUMN_SIZE_SIZE)) == -1 )
+		if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_SEARCH_COLUMN_SIZE_SIZE)) == -1 )
 		{
 			width = GW_VALUE_APP_SEARCH_COLUMN_SIZE_SIZE_DEFAULT;
 		}
 
 		gtk_clist_set_column_width ( clist, GW_VALUE_APP_SEARCH_COLUMN_SIZE_POSITION_DEFAULT, width);
 
-		if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_SEARCH_COLUMN_DATE_SIZE)) == -1 )
+		if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_SEARCH_COLUMN_DATE_SIZE)) == -1 )
 		{
 			width = GW_VALUE_APP_SEARCH_COLUMN_DATE_SIZE_DEFAULT;
 		}
 
 		gtk_clist_set_column_width ( clist, GW_VALUE_APP_SEARCH_COLUMN_DATE_POSITION_DEFAULT, width);
 
-		if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_SEARCH_COLUMN_CATEGORY_SIZE)) == -1 )
+		if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_SEARCH_COLUMN_CATEGORY_SIZE)) == -1 )
 		{
 			width = GW_VALUE_APP_SEARCH_COLUMN_CATEGORY_SIZE_DEFAULT;
 		}
 
 		gtk_clist_set_column_width ( clist, GW_VALUE_APP_SEARCH_COLUMN_DESCRIPTION_POSITION_DEFAULT, width);
 
-		if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_SEARCH_COLUMN_DESCRIPTION_SIZE)) == -1 )
+		if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_SEARCH_COLUMN_DESCRIPTION_SIZE)) == -1 )
 		{
 			width = GW_VALUE_APP_SEARCH_COLUMN_DESCRIPTION_SIZE_DEFAULT;
 		}
@@ -1069,7 +1069,7 @@ gint gw_notebook_search_clist_search_set_column_title ( void)
 		gtk_clist_set_column_width ( clist, GW_VALUE_APP_SEARCH_COLUMN_CATEGORY_POSITION_DEFAULT, width);
 
 		/* Sets columns width. */
-		if ( (autoresize = gw_application_manager_get_settings_tol ( GW_VALUE_APP_SEARCH_COLUMN_AUTORESIZE)) == -1 )
+		if ( (autoresize = gw_am_get_settings_tol ( GW_VALUE_APP_SEARCH_COLUMN_AUTORESIZE)) == -1 )
 		{
 			autoresize = GW_VALUE_APP_SEARCH_COLUMN_AUTORESIZE_DEFAULT;
 		}
@@ -1111,7 +1111,7 @@ gint gw_notebook_search_clist_search_set_column_title ( void)
 		gtk_clist_set_column_title ( clist, GW_VALUE_APP_SEARCH_COLUMN_DESCRIPTION_POSITION_DEFAULT, text_utf8);
 		g_free ( text_utf8);
 
-		if ( ((showed = gw_application_manager_get_settings ( GW_VALUE_APP_SEARCH_COLUMN_NAME_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
+		if ( ((showed = gw_am_get_settings ( GW_VALUE_APP_SEARCH_COLUMN_NAME_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
 		{
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_SEARCH_COLUMN_NAME_POSITION_DEFAULT, FALSE);
 		}
@@ -1120,7 +1120,7 @@ gint gw_notebook_search_clist_search_set_column_title ( void)
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_SEARCH_COLUMN_NAME_POSITION_DEFAULT, TRUE);
 		}
 
-		if ( ((showed = gw_application_manager_get_settings ( GW_VALUE_APP_SEARCH_COLUMN_DISK_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
+		if ( ((showed = gw_am_get_settings ( GW_VALUE_APP_SEARCH_COLUMN_DISK_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
 		{
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_SEARCH_COLUMN_DISK_POSITION_DEFAULT, FALSE);
 		}
@@ -1129,7 +1129,7 @@ gint gw_notebook_search_clist_search_set_column_title ( void)
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_SEARCH_COLUMN_DISK_POSITION_DEFAULT, TRUE);
 		}
 
-		if ( ((showed = gw_application_manager_get_settings ( GW_VALUE_APP_SEARCH_COLUMN_PATH_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
+		if ( ((showed = gw_am_get_settings ( GW_VALUE_APP_SEARCH_COLUMN_PATH_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
 		{
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_SEARCH_COLUMN_PATH_POSITION_DEFAULT, FALSE);
 		}
@@ -1138,7 +1138,7 @@ gint gw_notebook_search_clist_search_set_column_title ( void)
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_SEARCH_COLUMN_PATH_POSITION_DEFAULT, TRUE);
 		}
 
-		if ( ((showed = gw_application_manager_get_settings ( GW_VALUE_APP_SEARCH_COLUMN_SIZE_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
+		if ( ((showed = gw_am_get_settings ( GW_VALUE_APP_SEARCH_COLUMN_SIZE_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
 		{
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_SEARCH_COLUMN_SIZE_POSITION_DEFAULT, FALSE);
 		}
@@ -1147,7 +1147,7 @@ gint gw_notebook_search_clist_search_set_column_title ( void)
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_SEARCH_COLUMN_SIZE_POSITION_DEFAULT, TRUE);
 		}
 
-		if ( ((showed = gw_application_manager_get_settings ( GW_VALUE_APP_SEARCH_COLUMN_DATE_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
+		if ( ((showed = gw_am_get_settings ( GW_VALUE_APP_SEARCH_COLUMN_DATE_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
 		{
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_SEARCH_COLUMN_DATE_POSITION_DEFAULT, FALSE);
 		}
@@ -1156,7 +1156,7 @@ gint gw_notebook_search_clist_search_set_column_title ( void)
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_SEARCH_COLUMN_DATE_POSITION_DEFAULT, TRUE);
 		}
 
-		if ( ((showed = gw_application_manager_get_settings ( GW_VALUE_APP_SEARCH_COLUMN_CATEGORY_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
+		if ( ((showed = gw_am_get_settings ( GW_VALUE_APP_SEARCH_COLUMN_CATEGORY_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
 		{
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_SEARCH_COLUMN_CATEGORY_POSITION_DEFAULT, FALSE);
 		}
@@ -1165,7 +1165,7 @@ gint gw_notebook_search_clist_search_set_column_title ( void)
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_SEARCH_COLUMN_CATEGORY_POSITION_DEFAULT, TRUE);
 		}
 
-		if ( ((showed = gw_application_manager_get_settings ( GW_VALUE_APP_SEARCH_COLUMN_DESCRIPTION_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
+		if ( ((showed = gw_am_get_settings ( GW_VALUE_APP_SEARCH_COLUMN_DESCRIPTION_SHOW)) != NULL) && (strncmp ( showed, "0", 1) == 0) )
 		{
 			gtk_clist_set_column_visibility ( clist, GW_VALUE_APP_SEARCH_COLUMN_DESCRIPTION_POSITION_DEFAULT, FALSE);
 		}
