@@ -80,7 +80,7 @@ gint gw_catalog_compare_search_gulong ( GtkCList *clist, const gpointer ptr1, co
 					}
 					else
 					{
-						result = (((gw_application_manager_get_settings_tol ( GW_VALUE_APP_SEARCH_SORT_BY_TYPE)==0)||(type1==type2))?(nb1-nb2):(type1-type2));
+						result = (((gw_am_get_settings_tol ( GW_VALUE_APP_SEARCH_SORT_BY_TYPE)==0)||(type1==type2))?(nb1-nb2):(type1-type2));
 					}
 				}
 			}
@@ -137,7 +137,7 @@ gint gw_catalog_compare_search_gui64long ( GtkCList *clist, const gpointer ptr1,
 					}
 					else
 					{
-						result = (((gw_application_manager_get_settings_tol ( GW_VALUE_APP_SEARCH_SORT_BY_TYPE)==0)||(type1==type2))?(nb1-nb2):(type1-type2));
+						result = (((gw_am_get_settings_tol ( GW_VALUE_APP_SEARCH_SORT_BY_TYPE)==0)||(type1==type2))?(nb1-nb2):(type1-type2));
 					}
 				}
 			}
@@ -211,13 +211,13 @@ gint gw_catalog_compare_search_str ( GtkCList *clist, const gpointer ptr1, const
 					}
 					else
 					{
-						if ( gw_application_manager_get_settings_tol ( GW_VALUE_APP_SEARCH_SORT_CASE_SENSITIVE) == 1 )
+						if ( gw_am_get_settings_tol ( GW_VALUE_APP_SEARCH_SORT_CASE_SENSITIVE) == 1 )
 						{
-							result = (((gw_application_manager_get_settings_tol ( GW_VALUE_APP_SEARCH_SORT_BY_TYPE)==0)||(type1==type2))?strcmp ( str1, str2):(type1-type2));
+							result = (((gw_am_get_settings_tol ( GW_VALUE_APP_SEARCH_SORT_BY_TYPE)==0)||(type1==type2))?strcmp ( str1, str2):(type1-type2));
 						}
 						else
 						{
-							result = (((gw_application_manager_get_settings_tol ( GW_VALUE_APP_SEARCH_SORT_BY_TYPE)==0)||(type1==type2))?strcasecmp ( str1, str2):(type1-type2));
+							result = (((gw_am_get_settings_tol ( GW_VALUE_APP_SEARCH_SORT_BY_TYPE)==0)||(type1==type2))?strcasecmp ( str1, str2):(type1-type2));
 						}
 					}
 				}
@@ -288,7 +288,7 @@ gboolean gw_notebook_search_search_string_activate ( GtkWidget *entry, GtkWindow
 		if ( entry != NULL )
 		{
 			g_strdup_from_gtk_text ( gtk_entry_get_text ( GTK_ENTRY ( entry)), text);
-			gw_application_manager_set_settings ( GW_VALUE_APP_SEARCH_STRING, text);
+			gw_am_set_settings ( GW_VALUE_APP_SEARCH_STRING, text);
 		result = TRUE;
 	}
 	}
@@ -313,7 +313,7 @@ gboolean gw_notebook_search_search_button_click ( GtkWidget *bt, GtkWindow *w)
 	if ( w != NULL )
 	{
 		/* saves the new filled search string */
-		gw_application_manager_set_settings ( GW_VALUE_APP_SEARCH_STRING, gw_notebook_search_get_search_text ( w));
+		gw_am_set_settings ( GW_VALUE_APP_SEARCH_STRING, gw_notebook_search_get_search_text ( w));
 
 		if ( gw_gui_manager_main_interface_get_tree_root ( ) != NULL )
 		{
@@ -337,7 +337,7 @@ gboolean gw_notebook_search_search_button_click ( GtkWidget *bt, GtkWindow *w)
 				gw_msg_box_create ( w, _( "Search result"), _( "No item matched."));
 				/* Doesn't use it at time. It should be configured in the settings. */
 				/* gdk_beep ( );*/
-				gw_application_manager_beep ( );
+				gw_am_beep ( );
 			}
 
 			result = TRUE;
@@ -411,7 +411,7 @@ gint gw_notebook_search_option_use_case_sensitive_click ( GtkToggleButton *chk,
 
 	if ( chk != NULL)
 	{
-		gw_application_manager_set_settings ( GW_VALUE_APP_SEARCH_CASE_SENSITIVE, g_strdup_printf ( "%d", gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON ( chk))));
+		gw_am_set_settings ( GW_VALUE_APP_SEARCH_CASE_SENSITIVE, g_strdup_printf ( "%d", gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON ( chk))));
 		result = 0;
 	}
 
@@ -430,7 +430,7 @@ gint gw_notebook_search_option_search_type_click ( GtkToggleButton *chk, gpointe
 
 	if ( chk != NULL)
 	{
-		gw_application_manager_set_settings ( GW_VALUE_APP_SEARCH_TYPE, g_strdup_printf ( "%d", GPOINTER_TO_INT ( search_type)));
+		gw_am_set_settings ( GW_VALUE_APP_SEARCH_TYPE, g_strdup_printf ( "%d", GPOINTER_TO_INT ( search_type)));
 		result = 0;
 	}
 
@@ -449,7 +449,7 @@ gint gw_notebook_search_option_match_file_click ( GtkToggleButton *chk, GtkWindo
 
 	if ( chk != NULL)
 	{
-		gw_application_manager_set_settings ( GW_VALUE_APP_SEARCH_FILE_NAME, g_strdup_printf ( "%d", gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON ( chk))));
+		gw_am_set_settings ( GW_VALUE_APP_SEARCH_FILE_NAME, g_strdup_printf ( "%d", gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON ( chk))));
 		result = 0;
 	}
 
@@ -468,7 +468,7 @@ gint gw_notebook_search_option_match_folder_click ( GtkToggleButton *chk, GtkWin
 
 	if ( chk != NULL)
 	{
-		gw_application_manager_set_settings ( GW_VALUE_APP_SEARCH_FOLDER_NAME, g_strdup_printf ( "%d", gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON ( chk))));
+		gw_am_set_settings ( GW_VALUE_APP_SEARCH_FOLDER_NAME, g_strdup_printf ( "%d", gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON ( chk))));
 		result = 0;
 	}
 
@@ -487,7 +487,7 @@ gint gw_notebook_search_option_match_disk_click ( GtkToggleButton *chk, GtkWindo
 
 	if ( chk != NULL)
 	{
-		gw_application_manager_set_settings ( GW_VALUE_APP_SEARCH_DISK_NAME, g_strdup_printf ( "%d", gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON ( chk))));
+		gw_am_set_settings ( GW_VALUE_APP_SEARCH_DISK_NAME, g_strdup_printf ( "%d", gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON ( chk))));
 		result = 0;
 	}
 
@@ -506,7 +506,7 @@ gint gw_notebook_search_option_match_category_click ( GtkToggleButton *chk, GtkW
 
 	if ( chk != NULL)
 	{
-		gw_application_manager_set_settings ( GW_VALUE_APP_SEARCH_CATEGORY_NAME, g_strdup_printf ( "%d", gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON ( chk))));
+		gw_am_set_settings ( GW_VALUE_APP_SEARCH_CATEGORY_NAME, g_strdup_printf ( "%d", gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON ( chk))));
 		result = 0;
 	}
 
@@ -525,7 +525,7 @@ gint gw_notebook_search_option_match_description_click ( GtkToggleButton *chk, G
 
 	if ( chk != NULL)
 	{
-		gw_application_manager_set_settings ( GW_VALUE_APP_SEARCH_DESCRIPTION, g_strdup_printf ( "%d", gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON ( chk))));
+		gw_am_set_settings ( GW_VALUE_APP_SEARCH_DESCRIPTION, g_strdup_printf ( "%d", gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON ( chk))));
 		result = 0;
 	}
 
@@ -543,7 +543,7 @@ gint gw_notebook_search_clist_column_resized ( GtkCList *clist, gint column, gin
 	g_print ( "*** GW - %s (%d) :: %s()\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-	if ( (autoresize = gw_application_manager_get_settings_tol ( GW_VALUE_APP_EXPLORER_COLUMN_AUTORESIZE)) == -1 )
+	if ( (autoresize = gw_am_get_settings_tol ( GW_VALUE_APP_EXPLORER_COLUMN_AUTORESIZE)) == -1 )
 	{
 		autoresize = GW_VALUE_APP_EXPLORER_COLUMN_AUTORESIZE_DEFAULT;
 	}
@@ -555,25 +555,25 @@ gint gw_notebook_search_clist_column_resized ( GtkCList *clist, gint column, gin
 		{
 			switch ( column)
 			{
-				case GW_VALUE_APP_SEARCH_COLUMN_NAME_POSITION_DEFAULT:		gw_application_manager_set_settings ( GW_VALUE_APP_SEARCH_COLUMN_NAME_SIZE, g_strdup_printf ( "%d", width));
+				case GW_VALUE_APP_SEARCH_COLUMN_NAME_POSITION_DEFAULT:		gw_am_set_settings ( GW_VALUE_APP_SEARCH_COLUMN_NAME_SIZE, g_strdup_printf ( "%d", width));
 												break;
 
-				case GW_VALUE_APP_SEARCH_COLUMN_DISK_POSITION_DEFAULT:		gw_application_manager_set_settings ( GW_VALUE_APP_SEARCH_COLUMN_DISK_SIZE, g_strdup_printf ( "%d", width));
+				case GW_VALUE_APP_SEARCH_COLUMN_DISK_POSITION_DEFAULT:		gw_am_set_settings ( GW_VALUE_APP_SEARCH_COLUMN_DISK_SIZE, g_strdup_printf ( "%d", width));
 												break;
 
-				case GW_VALUE_APP_SEARCH_COLUMN_PATH_POSITION_DEFAULT:		gw_application_manager_set_settings ( GW_VALUE_APP_SEARCH_COLUMN_PATH_SIZE, g_strdup_printf ( "%d", width));
+				case GW_VALUE_APP_SEARCH_COLUMN_PATH_POSITION_DEFAULT:		gw_am_set_settings ( GW_VALUE_APP_SEARCH_COLUMN_PATH_SIZE, g_strdup_printf ( "%d", width));
 												break;
 
-				case GW_VALUE_APP_SEARCH_COLUMN_SIZE_POSITION_DEFAULT:		gw_application_manager_set_settings ( GW_VALUE_APP_SEARCH_COLUMN_SIZE_SIZE, g_strdup_printf ( "%d", width));
+				case GW_VALUE_APP_SEARCH_COLUMN_SIZE_POSITION_DEFAULT:		gw_am_set_settings ( GW_VALUE_APP_SEARCH_COLUMN_SIZE_SIZE, g_strdup_printf ( "%d", width));
 												break;
 
-				case GW_VALUE_APP_SEARCH_COLUMN_DATE_POSITION_DEFAULT:		gw_application_manager_set_settings ( GW_VALUE_APP_SEARCH_COLUMN_DATE_SIZE, g_strdup_printf ( "%d", width));
+				case GW_VALUE_APP_SEARCH_COLUMN_DATE_POSITION_DEFAULT:		gw_am_set_settings ( GW_VALUE_APP_SEARCH_COLUMN_DATE_SIZE, g_strdup_printf ( "%d", width));
 												break;
 
-				case GW_VALUE_APP_SEARCH_COLUMN_CATEGORY_POSITION_DEFAULT:	gw_application_manager_set_settings ( GW_VALUE_APP_SEARCH_COLUMN_CATEGORY_SIZE, g_strdup_printf ( "%d", width));
+				case GW_VALUE_APP_SEARCH_COLUMN_CATEGORY_POSITION_DEFAULT:	gw_am_set_settings ( GW_VALUE_APP_SEARCH_COLUMN_CATEGORY_SIZE, g_strdup_printf ( "%d", width));
 												break;
 
-				case GW_VALUE_APP_SEARCH_COLUMN_DESCRIPTION_POSITION_DEFAULT:	gw_application_manager_set_settings ( GW_VALUE_APP_SEARCH_COLUMN_DESCRIPTION_SIZE, g_strdup_printf ( "%d", width));
+				case GW_VALUE_APP_SEARCH_COLUMN_DESCRIPTION_POSITION_DEFAULT:	gw_am_set_settings ( GW_VALUE_APP_SEARCH_COLUMN_DESCRIPTION_SIZE, g_strdup_printf ( "%d", width));
 												break;
 
 				default:							break;
