@@ -17,6 +17,7 @@
  */
 
 
+#include <string.h> /* stcmp */
 #include "../gwsupport.h"
 #include "gwsettingscatalogfile.h"
 
@@ -272,7 +273,7 @@ gint gw_plugin_settings_catalog_file_pane_load ( GtkWidget *pane)
 			g_print ( "*** GW - %s (%d) :: %s() : getting the compression level...\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-			level = gw_application_manager_get_settings_tod ( GW_VALUE_APP_CATALOG_COMPRESSION_LEVEL);
+			level = gw_am_get_settings_tod ( GW_VALUE_APP_CATALOG_COMPRESSION_LEVEL);
 
 #ifdef GW_DEBUG_PLUGIN_SETTINGS_COMPONENT
 			g_print ( "*** GW - %s (%d) :: %s() : compression level is %f\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, level);
@@ -298,7 +299,7 @@ gint gw_plugin_settings_catalog_file_pane_load ( GtkWidget *pane)
 			g_print ( "*** GW - %s (%d) :: %s() : getting the history size...\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-			size = gw_application_manager_get_settings_tod ( GW_VALUE_APP_RECENT_SIZE);
+			size = gw_am_get_settings_tod ( GW_VALUE_APP_RECENT_SIZE);
 
 #ifdef GW_DEBUG_PLUGIN_SETTINGS_COMPONENT
 			g_print ( "*** GW - %s (%d) :: %s() : history size is %f\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, size);
@@ -323,7 +324,7 @@ gint gw_plugin_settings_catalog_file_pane_load ( GtkWidget *pane)
 			g_print ( "*** GW - %s (%d) :: %s() : getting the autoload option...\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-			autoload = gw_application_manager_get_settings_tod ( GW_VALUE_APP_CATALOG_AUTOLOAD);
+			autoload = gw_am_get_settings_tod ( GW_VALUE_APP_CATALOG_AUTOLOAD);
 
 #ifdef GW_DEBUG_PLUGIN_SETTINGS_COMPONENT
 			g_print ( "*** GW - %s (%d) :: %s() : autoload option is %f\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, autoload);
@@ -347,7 +348,7 @@ gint gw_plugin_settings_catalog_file_pane_load ( GtkWidget *pane)
 			g_print ( "*** GW - %s (%d) :: %s() : getting the autoload last option...\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-			autoload = gw_application_manager_get_settings_tod ( GW_VALUE_APP_CATALOG_AUTOLOAD_LAST);
+			autoload = gw_am_get_settings_tod ( GW_VALUE_APP_CATALOG_AUTOLOAD_LAST);
 
 #ifdef GW_DEBUG_PLUGIN_SETTINGS_COMPONENT
 			g_print ( "*** GW - %s (%d) :: %s() : autoload last option is %f\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, autoload);
@@ -371,7 +372,7 @@ gint gw_plugin_settings_catalog_file_pane_load ( GtkWidget *pane)
 			g_print ( "*** GW - %s (%d) :: %s() : getting the autoload selected option...\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-			autoload = gw_application_manager_get_settings_tod ( GW_VALUE_APP_CATALOG_AUTOLOAD_SELECTED);
+			autoload = gw_am_get_settings_tod ( GW_VALUE_APP_CATALOG_AUTOLOAD_SELECTED);
 
 #ifdef GW_DEBUG_PLUGIN_SETTINGS_COMPONENT
 			g_print ( "*** GW - %s (%d) :: %s() : autoload seletec option is %f\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, autoload);
@@ -395,7 +396,7 @@ gint gw_plugin_settings_catalog_file_pane_load ( GtkWidget *pane)
 			g_print ( "*** GW - %s (%d) :: %s() : getting the autoload file path...\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
-			value = gw_application_manager_get_settings ( GW_VALUE_APP_CATALOG_AUTOLOAD_FILEPATH);
+			value = gw_am_get_settings ( GW_VALUE_APP_CATALOG_AUTOLOAD_FILEPATH);
 
 #ifdef GW_DEBUG_PLUGIN_SETTINGS_COMPONENT
 			if ( value != NULL ) {
@@ -468,7 +469,7 @@ gint gw_plugin_settings_catalog_file_pane_apply ( GtkWidget *pane)
 		if ( (entry = GTK_ENTRY ( gtk_object_get_data ( GTK_OBJECT ( pane), GW_PLUGIN_SETTINGS_CATALOG_COMPRESSION_LEVEL_ENTRY))) != NULL)
 		{
 			g_strdup_from_gtk_text ( gtk_entry_get_text ( GTK_ENTRY ( entry)), value);
-			gw_application_manager_set_settings ( GW_VALUE_APP_CATALOG_COMPRESSION_LEVEL, value);
+			gw_am_set_settings ( GW_VALUE_APP_CATALOG_COMPRESSION_LEVEL, value);
 		}
 
 		entry = NULL;
@@ -477,7 +478,7 @@ gint gw_plugin_settings_catalog_file_pane_apply ( GtkWidget *pane)
 		if ( (entry = GTK_ENTRY ( gtk_object_get_data ( GTK_OBJECT ( pane), GW_PLUGIN_SETTINGS_CATALOG_HISTORY_SIZE_ENTRY))) != NULL)
 		{
 			g_strdup_from_gtk_text ( gtk_entry_get_text ( GTK_ENTRY ( entry)), value);
-			gw_application_manager_set_settings ( GW_VALUE_APP_RECENT_SIZE, value);
+			gw_am_set_settings ( GW_VALUE_APP_RECENT_SIZE, value);
 		}
 
 		entry = NULL;
@@ -486,7 +487,7 @@ gint gw_plugin_settings_catalog_file_pane_apply ( GtkWidget *pane)
 		if ( (chk = GTK_TOGGLE_BUTTON ( gtk_object_get_data ( GTK_OBJECT ( pane), GW_PLUGIN_SETTINGS_CATALOG_AUTOLOAD_CHK))) != NULL)
 		{
 			bool_value = gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON ( chk));
-			gw_application_manager_set_settings ( GW_VALUE_APP_CATALOG_AUTOLOAD, g_strdup_printf ( "%d", (gint)bool_value));
+			gw_am_set_settings ( GW_VALUE_APP_CATALOG_AUTOLOAD, g_strdup_printf ( "%d", (gint)bool_value));
 		}
 
 		entry = NULL;
@@ -495,7 +496,7 @@ gint gw_plugin_settings_catalog_file_pane_apply ( GtkWidget *pane)
 		if ( (chk = GTK_TOGGLE_BUTTON ( gtk_object_get_data ( GTK_OBJECT ( pane), GW_PLUGIN_SETTINGS_CATALOG_AUTOLOAD_LAST_RADIO))) != NULL)
 		{
 			bool_value = gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON ( chk));
-			gw_application_manager_set_settings ( GW_VALUE_APP_CATALOG_AUTOLOAD_LAST, g_strdup_printf ( "%d", (gint)bool_value));
+			gw_am_set_settings ( GW_VALUE_APP_CATALOG_AUTOLOAD_LAST, g_strdup_printf ( "%d", (gint)bool_value));
 		}
 
 		entry = NULL;
@@ -504,7 +505,7 @@ gint gw_plugin_settings_catalog_file_pane_apply ( GtkWidget *pane)
 		if ( (chk = GTK_TOGGLE_BUTTON ( gtk_object_get_data ( GTK_OBJECT ( pane), GW_PLUGIN_SETTINGS_CATALOG_AUTOLOAD_SELECTED_RADIO))) != NULL)
 		{
 			bool_value = gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON ( chk));
-			gw_application_manager_set_settings ( GW_VALUE_APP_CATALOG_AUTOLOAD_SELECTED, g_strdup_printf ( "%d", (gint)bool_value));
+			gw_am_set_settings ( GW_VALUE_APP_CATALOG_AUTOLOAD_SELECTED, g_strdup_printf ( "%d", (gint)bool_value));
 		}
 
 		entry = NULL;
@@ -513,7 +514,7 @@ gint gw_plugin_settings_catalog_file_pane_apply ( GtkWidget *pane)
 		if ( (entry = GTK_ENTRY ( gtk_object_get_data ( GTK_OBJECT ( pane), GW_PLUGIN_SETTINGS_CATALOG_AUTOLOAD_ENTRY))) != NULL)
 		{
 			g_strdup_from_gtk_text ( gtk_entry_get_text ( GTK_ENTRY ( entry)), value);
-			gw_application_manager_set_settings ( GW_VALUE_APP_CATALOG_AUTOLOAD_FILEPATH, value);
+			gw_am_set_settings ( GW_VALUE_APP_CATALOG_AUTOLOAD_FILEPATH, value);
 		}
 
 		entry = NULL;
@@ -542,7 +543,7 @@ gint gw_plugin_settings_catalog_file_btn_clear_history_click ( GtkButton *btn, G
 
 	if ( pane != NULL)
 	{
-		gw_application_manager_set_settings ( GW_VALUE_APP_RECENTS_FILES, g_strdup ( ""));
+		gw_am_set_settings ( GW_VALUE_APP_RECENTS_FILES, g_strdup ( ""));
 		gw_gui_manager_main_interface_update_all ( );
 		result = 0;
 	}
