@@ -41,6 +41,7 @@
 
 #include "data/gwdata.h"
 #include "gui/gwgui.h"
+#include "gwpluginsmanager.h"
 
 
 /*! @define	GWECATNOMODIFIED	An error code : catalog isn't modified */
@@ -59,13 +60,12 @@
  * @field	user_gwhere_settings_file	path of the user gwhere settings file
  * @field	settings			current settings
  */
-typedef struct gw_application_settings
-{
+typedef struct gw_application_settings {
 	gchar *user_name;
 	gchar *user_gwhere_home;
 	gchar *user_gwhere_settings_file;
 	GWSettings *settings;
-}GWApplicationSettings;
+} GWApplicationSettings;
 
 
 typedef struct gw_mail_s
@@ -629,7 +629,7 @@ typedef struct gw_mail_s
 
 
 /*!
- * @function	gw_application_manager_init
+ * @function	gw_am_init
  * @abstract	Initializes the application settings.
  * @discussion	This function initializes the application settings.
  * @param	filepath	file path of the catalog to load
@@ -637,22 +637,22 @@ typedef struct gw_mail_s
  *		Returns <i>0</i> when it's done.<br>
  *		Returns <i>-1</i> when an error occured.
  */
-gint gw_application_manager_init ( gint argc, gchar *argv[]);
+gint gw_am_init ( gint argc, gchar *argv[]);
 
 
 /*!
- * @function	gw_application_manager_load_default_settings
+ * @function	gw_am_load_default_settings
  * @abstract	Loads default settings.
  * @discussion	This function loads default settings.
  * @result	an error code.<br>
  *		Returns <i>0</i> when it's done.<br>
  *		Returns <i>-1</i> when an error occured.
  */
-gint gw_application_manager_load_default_settings ( );
+gint gw_am_load_default_settings ( );
 
 
 /*!
- * @function	gw_application_manager_can_send_mail
+ * @function	gw_am_can_send_mail
  * @abstract	Checks if can send mails.
  * @discussion	This function checks if can send mails. To
  *		send mails, the user must configure mail
@@ -661,42 +661,76 @@ gint gw_application_manager_load_default_settings ( );
  *		Returns <i>FALSE</i> if cannot send mails or
  *		when an error occured.
  */
-gboolean gw_application_manager_can_send_mail ( );
+gboolean gw_am_can_send_mail ( );
 
 
 /*!
- * @function	gw_application_manager_get_settings_tod
+ * @function	gw_am_get_settings_tod
  * @abstract	Gets the gfloat value of a setting.
  * @discussion	This function gets the gfloat value of a setting.
  * @param	name	name of setting
  * @result	the gfloat value of setting.
  */
-gfloat gw_application_manager_get_settings_tod ( const gchar *name);
+gfloat gw_am_get_settings_tod ( const gchar *name);
 
 
 /*!
- * @function	gw_application_manager_get_settings_tol
+ * @function	gw_am_get_settings_tol
  * @abstract	Gets the gint value of a setting.
  * @discussion	This function gets the gint value of a setting.
  * @param	name	name of setting
  * @result	the gint value of setting.
  */
-gint gw_application_manager_get_settings_tol ( const gchar *name);
+gint gw_am_get_settings_tol ( const gchar *name);
 
 
 /*!
- * @function	gw_application_manager_get_settings
+ * @function	gw_am_get_settings_tolx
+ * @abstract	Gets the gint value of a setting.
+ * @discussion	This function gets the gint value of a setting.
+ * @param	name	name of setting
+ * @param	value	the default value
+ * @result	the gint value of setting or the default value if
+ *		doesn't exist.
+ */
+gint gw_am_get_settings_tolx ( const gchar *name, const gint value);
+
+
+/*!
+ * @function	gw_am_get_settings_tob
+ * @abstract	Gets the gboolean value of a setting.
+ * @discussion	This function gets the gboolean value of a setting.
+ * @param	name	name of setting
+ * @result	the gboolean value of setting.
+ */
+gboolean gw_am_get_settings_tob ( const gchar *name);
+
+
+/*!
+ * @function	gw_am_get_settings_tobx
+ * @abstract	Gets the gboolean value of a setting.
+ * @discussion	This function gets the gboolean value of a setting.
+ * @param	name	name of setting
+ * @param	value	the default value
+ * @result	the gboolean value of setting or the default value if
+ *		doesn't exist.
+ */
+gboolean gw_am_get_settings_tobx ( const gchar *name, const gboolean value);
+
+
+/*!
+ * @function	gw_am_get_settings
  * @abstract	Gets the value of a setting.
  * @discussion	This function gets the value of a setting.
  * @param	name	name of setting
  * @result	the value of setting.<br>
  *		Returns <i>NULL</i> when an error occured.
  */
-gchar * gw_application_manager_get_settings ( const gchar *name);
+gchar * gw_am_get_settings ( const gchar *name);
 
 
 /*!
- * @function	gw_application_manager_get_settings
+ * @function	gw_am_get_settings
  * @abstract	Gets the value of a setting.
  * @discussion	This function gets the value of a setting.
  * @param	name	name of setting
@@ -705,7 +739,7 @@ gchar * gw_application_manager_get_settings ( const gchar *name);
  *		Returns <i>0</i> when it's done.<br>
  *		Returns <i>-1</i> when an error occured.
  */
-gint gw_application_manager_set_settings ( const gchar *name, gchar *value);
+gint gw_am_set_settings ( const gchar *name, gchar *value);
 
 
 /*!
@@ -715,33 +749,33 @@ gint gw_application_manager_set_settings ( const gchar *name, gchar *value);
  * @result	the catalog file informations.<br>
  *		Returns <i>NULL</i> when no catalog opened or when an error occured.
  */
-struct catalog_file_info * gw_application_manager_get_current_catalog ( void);
+struct catalog_file_info * gw_am_get_current_catalog ( void);
 
 
 /*!
- * @function	gw_application_manager_exit
+ * @function	gw_am_exit
  * @abstract	Exits the application and processes to all savings.
  * @discussion	This function exits the application and processes to all savings.
  * @result	an error code.<br>
  *		Returns <i>0</i> when it's done.<br>
  *		Returns <i>-1</i> when an error occured.
  */
-gint gw_application_manager_exit ( );
+gint gw_am_exit ( );
 
 
 /*!
- * @function	gw_application_manager_send_mail
+ * @function	gw_am_send_mail
  * @abstract	Sends an mail from the application.
  * @discussion	This function sends an mail from the application.
  * @result	an error code.<br>
  *		Returns <i>0</i> when it's done.<br>
  *		Returns <i>-1</i> when an error occured.
  */
-gint gw_application_manager_send_mail ( GWMail *mail);
+gint gw_am_send_mail ( GWMail *mail);
 
 
 /*!
- * @function	gw_application_manager_load_catalog
+ * @function	gw_am_load_catalog
  * @abstract	Loads a catalog in the application.
  * @discussion	This function loads a catalog in the application.
  * @param	filepath	catalog file path
@@ -749,11 +783,11 @@ gint gw_application_manager_send_mail ( GWMail *mail);
  *		Returns <i>0</i> when it's done.<br>
  *		Returns <i>-1</i> when an error occured.
  */
-gint gw_application_manager_load_catalog ( const char *filepath);
+gint gw_am_load_catalog ( const char *filepath);
 
 
 /*!
- * @function	gw_application_manager_save_catalog
+ * @function	gw_am_save_catalog
  * @abstract	Saves the current opened a catalog in the application.
  * @discussion	This function saves the current opened a catalog in the application.
  * @param	path	the new file name to save the catalog
@@ -761,11 +795,11 @@ gint gw_application_manager_load_catalog ( const char *filepath);
  *		Returns <i>0</i> when it's done.<br>
  *		Returns <i>-1</i> when an error occured.
  */
-gint gw_application_manager_save_catalog ( const gchar *path);
+gint gw_am_save_catalog ( const gchar *path);
 
 
 /*!
- * @function	gw_application_manager_close_catalog
+ * @function	gw_am_close_catalog
  * @abstract	Closes the current opened a catalog in the application.
  * @discussion	This function closes the current opened a catalog in the application.
  * @param	save	<i>TRUE</i> if it should check if the catalog is modified before close it.
@@ -773,11 +807,11 @@ gint gw_application_manager_save_catalog ( const gchar *path);
  *		Returns <i>0</i> when it's done.<br>
  *		Returns <i>-1</i> when an error occured.
  */
-gint gw_application_manager_close_catalog ( gboolean save);
+gint gw_am_close_catalog ( gboolean save);
 
 
 /*!
- * @function	gw_application_manager_add_recent_file
+ * @function	gw_am_add_recent_file
  * @abstract	Adds an entry to the recents opened catalog files list.
  * @discussion	This function adds an entry to the recents opened catalog files list.
  * @param	filepath	file path to add
@@ -785,11 +819,11 @@ gint gw_application_manager_close_catalog ( gboolean save);
  *		Returns <i>0</i> when it's done.<br>
  *		Returns <i>-1</i> when an error occured.
  */
-gint gw_application_manager_add_recent_file ( const gchar *filepath);
+gint gw_am_add_recent_file ( const gchar *filepath);
 
 
 /*!
- * @function	gw_application_manager_load_catalog_from_recents_files
+ * @function	gw_am_load_catalog_from_recents_files
  * @abstract	Loads a catalog in the application from the recents files list.
  * @discussion	This function loads a catalog in the application from the recents files list.
  * @param	index	position in the recents files list (start at <i>0</i>)
@@ -797,11 +831,11 @@ gint gw_application_manager_add_recent_file ( const gchar *filepath);
  *		Returns <i>0</i> when it's done.<br>
  *		Returns <i>-1</i> when an error occured.
  */
-gint gw_application_manager_load_catalog_from_recents_files ( const guint index);
+gint gw_am_load_catalog_from_recents_files ( const guint index);
 
 
 /*!
- * @function	gw_application_manager_get_catalog_path_name_from_recents_files
+ * @function	gw_am_get_catalog_path_name_from_recents_files
  * @abstract	Gets the catalog path name in the application from the recents files list.
  * @discussion	This function gets the catalog path name in the application from
  *		the recents files list. It is a new allocated string (must be freed
@@ -810,11 +844,11 @@ gint gw_application_manager_load_catalog_from_recents_files ( const guint index)
  * @result	the catalog path name.<br>
  *		Returns <i>NULL</i> when an error occured.
  */
-gchar * gw_application_manager_get_catalog_path_name_from_recents_files ( const guint index);
+gchar * gw_am_get_catalog_path_name_from_recents_files ( const guint index);
 
 
 /*!
- * @function	gw_application_manager_log_msg
+ * @function	gw_am_log_msg
  * @abstract	Logs a message.
  * @discussion	This function logs a message.
  * @param	level	log level
@@ -823,15 +857,15 @@ gchar * gw_application_manager_get_catalog_path_name_from_recents_files ( const
  * @param	line	line where the log is invoked
  * @param	msg	message to log
  */
-void gw_application_manager_log_msg ( const gint level, const gchar *file, const gint line, const gchar *function, const gchar *msg, ...);
+void gw_am_log_msg ( const gint level, const gchar *file, const gint line, const gchar *function, const gchar *msg, ...);
 
 
 /*!
- * @function	gw_application_manager_beep
+ * @function	gw_am_beep
  * @abstract	Emits a short beep.
  * @discussion	This function emits a short beep.
  */
-void gw_application_manager_beep ( );
+void gw_am_beep ( );
 
 
 /*!
@@ -864,4 +898,18 @@ GWSettingsExplorerField ** gw_plugin_settings_explorer_file_get_all_fields ( voi
 GWSettingsExplorerField ** gw_plugin_settings_search_get_all_fields ( void);
 
 
+void gw_am_set_current_catalog_context ( GWDBContext * context);
+
+
+GWDBContext * gw_am_get_current_catalog_context ( );
+
+
+gint gw_am_import_catalog_from ( GWCatalogPlugin *oplugin, GWCatalogPlugin *iplugin, gchar *db_name, gchar *short_db_name);
+
+
+gint gw_am_export_catalog_to ( GWDBContext *context, GWCatalogPlugin *plugin, gchar *db_name, gchar *short_db_name);
+
+
+gint gw_am_new_catalog ( const gchar *name);
+
 #endif
