@@ -94,7 +94,7 @@
 #include "gwsupermount.h"
 
 
-gint gw_device_manager_device_load_to_vfs_stats ( struct vfs_stats *p, gchar *dir)
+gint gw_dm_device_load_to_vfs_stats ( struct vfs_stats *p, gchar *dir)
 {
 	/* This function loads all information about a file system designed by
 	   his full path name (stored in the parameter "dir") as "/mnt/cdrom".
@@ -111,14 +111,14 @@ gint gw_device_manager_device_load_to_vfs_stats ( struct vfs_stats *p, gchar *di
 
 
 #ifdef GW_DEBUG_MODE
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
 #endif
 
 	if ( p == NULL )
 	{
 		/* The virtual file system hasn't been allocated */
 #ifdef GW_DEBUG_MODE
-		gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "VFS is null");
+		gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "VFS is null");
 #endif
 
 		return -1;
@@ -128,7 +128,7 @@ gint gw_device_manager_device_load_to_vfs_stats ( struct vfs_stats *p, gchar *di
 	{
 		/* The file system path is NULL */
 #ifdef GW_DEBUG_MODE
-		gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "filesystem path is null");
+		gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "filesystem path is null");
 #endif
 
 		return -1;
@@ -136,13 +136,13 @@ gint gw_device_manager_device_load_to_vfs_stats ( struct vfs_stats *p, gchar *di
 
 #if defined ( OS_LINUX)
 	/* Checks if the device is in the mounted device table (/etc/mtab) */
-	if ( gw_device_manager_search_disk_in_tab_file_to_vfs_stats ( p, "/etc/mtab", dir) == 0 )
+	if ( gw_dm_search_disk_in_tab_file_to_vfs_stats ( p, "/etc/mtab", dir) == 0 )
 	{
 		return 0;
 	}
 
 	/* Checks if the device is in the mountabled device table (/etc/fstab) */
-	if ( gw_device_manager_search_disk_in_tab_file_to_vfs_stats ( p, "/etc/fstab", dir) == 0 )
+	if ( gw_dm_search_disk_in_tab_file_to_vfs_stats ( p, "/etc/fstab", dir) == 0 )
 	{
 		return 0;
 	}
@@ -155,7 +155,7 @@ gint gw_device_manager_device_load_to_vfs_stats ( struct vfs_stats *p, gchar *di
 	vfs_stats_set_dir ( p, g_strdup ( dir));
 	vfs_stats_set_options ( p, NULL);
 
-	if ( gw_device_disk_in_drive ( dir) )
+	if ( gw_dm_is_disk_in_drive ( dir) )
 	{
 		gw_fs_get_type ( device_name, &device_type);
 		if ( device_type == NULL )
@@ -229,7 +229,7 @@ gint gw_device_manager_device_load_to_vfs_stats ( struct vfs_stats *p, gchar *di
 
 
 
-gboolean gw_device_manager_disk_try_mount_from_vfs_stats ( struct vfs_stats *p)
+gboolean gw_dm_disk_try_mount_from_vfs_stats ( struct vfs_stats *p)
 {
 /*
 // First methode failed : single user cannot use mount()
@@ -257,9 +257,9 @@ g_print ( "try_mount : can mount\n");
 */
 /*
 // Second methode failed : cannot detect if the device is allready mounted
-	if ( gw_device_manager_disk_mount_from_vfs_stats ( p) == TRUE )
+	if ( gw_dm_disk_mount_from_vfs_stats ( p) == TRUE )
 	{
-		gw_device_manager_disk_umount_from_vfs_stats ( p);
+		gw_dm_disk_umount_from_vfs_stats ( p);
 
 		return TRUE;
 	}
@@ -268,17 +268,17 @@ g_print ( "try_mount : can mount\n");
 */
 /*
 // Third methode failed : umount an umounted device doesn't failed
-	if ( gw_device_manager_disk_umount_from_vfs_stats ( p) == TRUE )
+	if ( gw_dm_disk_umount_from_vfs_stats ( p) == TRUE )
 	{
-		gw_device_manager_disk_mount_from_vfs_stats ( p);
+		gw_dm_disk_mount_from_vfs_stats ( p);
 
 		return TRUE;
 	}
 	else
 	{
-		if ( gw_device_manager_disk_mount_from_vfs_stats ( p) == TRUE )
+		if ( gw_dm_disk_mount_from_vfs_stats ( p) == TRUE )
 		{
-			gw_device_manager_disk_umount_from_vfs_stats ( p);
+			gw_dm_disk_umount_from_vfs_stats ( p);
 
 			return TRUE;
 		}
@@ -339,7 +339,7 @@ g_print ( "try_mount : can mount\n");
 }
 
 
-gint gw_device_manager_search_disk_in_tab_file_to_vfs_stats ( struct vfs_stats *p, const gchar *file_tab, const gchar *dir)
+gint gw_dm_search_disk_in_tab_file_to_vfs_stats ( struct vfs_stats *p, const gchar *file_tab, const gchar *dir)
 {
 	/* This function is used only on mount support systems.
 	   It searches all information about the file system
@@ -347,8 +347,8 @@ gint gw_device_manager_search_disk_in_tab_file_to_vfs_stats ( struct vfs_stats *
 	   "dir") as "/mnt/cdrom" in the designed "mount table"
 	   (stored in the parameter "file_tab").
 	*/
-	FILE *tab = NULL;
 #if defined ( OS_LINUX) || defined ( OS_CYGWIN)
+	FILE *tab = NULL;
 	struct mntent *partition = NULL;
 	struct statfs sts;
 	gchar *volume_name = NULL;
@@ -357,7 +357,7 @@ gint gw_device_manager_search_disk_in_tab_file_to_vfs_stats ( struct vfs_stats *
 
 
 #ifdef GW_DEBUG_MODE
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
 #endif
 
 	if ( p == NULL )
@@ -396,11 +396,11 @@ gint gw_device_manager_search_disk_in_tab_file_to_vfs_stats ( struct vfs_stats *
 					vfs_stats_set_ismounted ( p, FALSE);
 				}
 
-				if ( gw_device_manager_disk_can_mounted_from_vfs_stats ( p) )
+				if ( gw_dm_disk_can_mounted_from_vfs_stats ( p) )
 				{
-					if ( !gw_device_manager_disk_is_mounted_from_vfs_stats ( p) )
+					if ( !gw_dm_disk_is_mounted_from_vfs_stats ( p) )
 					{
-						has_mounted = gw_device_manager_disk_mount_from_vfs_stats ( p);
+						has_mounted = gw_dm_disk_mount_from_vfs_stats ( p);
 					}
 
 					if ( statfs ( dir, &sts) != -1 )
@@ -460,7 +460,7 @@ gint gw_device_manager_search_disk_in_tab_file_to_vfs_stats ( struct vfs_stats *
 
 					if ( !vfs_stats_get_ismounted ( p) && has_mounted )
 					{
-						gw_device_manager_disk_umount_from_vfs_stats ( p);
+						gw_dm_disk_umount_from_vfs_stats ( p);
 					}
 				}
 				else
@@ -489,43 +489,38 @@ gint gw_device_manager_search_disk_in_tab_file_to_vfs_stats ( struct vfs_stats *
 }
 
 
-gboolean gw_device_manager_disk_mount_from_vfs_stats ( struct vfs_stats *p)
-{
+gboolean gw_dm_disk_mount_from_vfs_stats ( struct vfs_stats *p) {
 	/* This function mount a file system with the external program "mount". */
 #if defined ( OS_LINUX) || defined ( OS_CYGWIN) || defined ( OS_FREEBSD) || defined ( OS_OPENBSD) || defined ( OS_NETBSD) || defined ( OS_MACOS) || defined ( OS_MACOSX) || defined ( OS_DARWIN)
 	int pid;		/* pid number		*/
-	int status;	/* process status		*/
-	int fd[2];		/* pipe descriptor		*/
+	int status;		/* process status	*/
+	int fd[2];		/* pipe descriptor	*/
 	char *argv[4] = {"mount", vfs_stats_get_dir ( p), 0};
  	char retour[201];
 	struct statfs stat_fs;
 
 
 #ifdef GW_DEBUG_MODE
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
 #endif
 
-	/* To prevent unexpected mount with supermount on Mandrake. */
-	if ( (vfs_stats_get_type ( p) != NULL) && (strncmp ( vfs_stats_get_type ( p), "supermount", 10) == 0 ) )
-	{
+	/* To prevent unexpected mount with supermount on Mandrake or submount on SuSe. */
+	if ( vfs_stats_get_type ( p) != NULL &&
+		((strncmp ( vfs_stats_get_type ( p), "supermount", 10) == 0 ) || (strncmp ( vfs_stats_get_type ( p), "subfs", 5) == 0 )) ) {
 		return statfs ( vfs_stats_get_dir ( p), &stat_fs);
 	}
 
 	/* Creates pipe */
-	if ( pipe ( fd) != 0 )
-	{
+	if ( pipe ( fd) != 0 ) {
 		/* Cannot create pipe */
-
 		perror ( "pipe");
-
 		return FALSE;
 	}
 
 	/* Creates a fork */
 	pid = fork (  );
 
-	if ( pid == 0 )
-	{
+	if ( pid == 0 ) {
 		/* If it's the child */
 		close ( fd[0]);
 		close ( 2);
@@ -535,34 +530,28 @@ gboolean gw_device_manager_disk_mount_from_vfs_stats ( struct vfs_stats *p)
 		dup2 ( fd[1], 2);
 		close ( fd[1]);
 
-		if ( execv ( GW_PROG_PATH_MOUNT, argv) == -1 )
-		{
+		if ( execv ( GW_PROG_PATH_MOUNT, argv) == -1 ) {
 			perror ( "execv");
 		}
 
 		exit ( 127);
-	}
-	else
-	{
+	} else {
 		/* If it's the parent */
-		if ( pid == -1 )
-		{
+		if ( pid == -1 ) {
 			perror ( "fork");
 		}
 	}
 
 	close ( fd[1]);
 
-        	/* Gets the pipe data */
+	/* Gets the pipe data */
 	gw_pipe_get_data ( fd[0], retour);
 
-	if ( waitpid ( pid, & status, 0) == -1 )
-	{
+	if ( waitpid ( pid, & status, 0) == -1 ) {
 		perror ( "waitpid");
 	}
 
-	 if ( WEXITSTATUS ( status) != 0 )
-	 {
+	 if ( WEXITSTATUS ( status) != 0 ) {
 		 return FALSE;
 	 }
 #endif
@@ -570,31 +559,29 @@ gboolean gw_device_manager_disk_mount_from_vfs_stats ( struct vfs_stats *p)
 }
 
 
-gboolean gw_device_manager_disk_umount_from_vfs_stats ( struct vfs_stats *p)
-{
+gboolean gw_dm_disk_umount_from_vfs_stats ( struct vfs_stats *p) {
 #if defined ( OS_LINUX) || defined ( OS_CYGWIN) || defined ( OS_FREEBSD) || defined ( OS_OPENBSD) || defined ( OS_NETBSD) || defined ( OS_MACOS) || defined ( OS_MACOSX) || defined ( OS_DARWIN)
 	/* This function try to unmount the file system with the externalm program "umount". */
 	gint pid;		/* pid number		*/
-	gint status;	/* process status		*/
-	gint fd[2];		/* pipe descriptor		*/
+	gint status;		/* process status	*/
+	gint fd[2];		/* pipe descriptor	*/
 	gchar *argv[4] =  {"umount", vfs_stats_get_dir ( p), 0};
  	gchar retour[201];
 	struct statfs stat_fs;
 
 
 #ifdef GW_DEBUG_MODE
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
 #endif
 
-	/* To prevent unexpected mount with supermount on Mandrake. */
-	if ( (vfs_stats_get_type ( p) != NULL) && (strncmp ( vfs_stats_get_type ( p), "supermount", 10) == 0 ) )
-	{
+	/* To prevent unexpected mount with supermount on Mandrake or submount on SuSe. */
+	if ( (vfs_stats_get_type ( p) != NULL) &&
+		((strncmp ( vfs_stats_get_type ( p), "supermount", 10) == 0 ) || (strncmp ( vfs_stats_get_type ( p), "subfs", 5) == 0 )) ) {
 		return statfs ( vfs_stats_get_dir ( p), &stat_fs);
 	}
 
 	/* Creates pipe */
-	if ( pipe ( fd) != 0 )
-	{
+	if ( pipe ( fd) != 0 ) {
 		perror ( "pipe");
 
 		return FALSE;
@@ -602,8 +589,7 @@ gboolean gw_device_manager_disk_umount_from_vfs_stats ( struct vfs_stats *p)
 
 	/* Creates fork */
 	pid = fork ( );
-	if ( pid == 0 )
-	{
+	if ( pid == 0 ) {
 		/* If it's the child */
 		close ( fd[0]);
 		close ( 2);
@@ -613,18 +599,14 @@ gboolean gw_device_manager_disk_umount_from_vfs_stats ( struct vfs_stats *p)
 		dup2 ( fd[1], 2);
 		close ( fd[1]);
 
-		if ( execv ( GW_PROG_PATH_UMOUNT, argv) == -1 )
-		{
+		if ( execv ( GW_PROG_PATH_UMOUNT, argv) == -1 ) {
 			perror ( "execv");
 		}
 
 		exit ( 127);
-	}
-	else
-	{
+	} else {
 		/* If it's the parent */
-		if ( pid == -1 )
-		{
+		if ( pid == -1 ) {
 			perror ( "fork");
 		}
 	}
@@ -635,14 +617,11 @@ gboolean gw_device_manager_disk_umount_from_vfs_stats ( struct vfs_stats *p)
 	gw_pipe_get_data ( fd[0], retour);
 
 	/* Waits the child process end */
-	if ( waitpid ( pid, & status, 0) == -1 )
-	{
+	if ( waitpid ( pid, & status, 0) == -1 ) {
 		perror ( "waitpid");
 	}
 
-	 if ( WEXITSTATUS ( status) != 0 )
-	 {
-
+	 if ( WEXITSTATUS ( status) != 0 ) {
 		 return FALSE;
 	 }
 
@@ -657,7 +636,7 @@ gint gw_pipe_get_data ( gint entry, gchar * line)
 
 
 #ifdef GW_DEBUG_MODE
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
 #endif
 
 	while ( (nb = read ( entry, line, 200)) > 0 )
@@ -674,13 +653,13 @@ gint gw_pipe_get_data ( gint entry, gchar * line)
 }
 
 
-gint gw_device_manager_disk_get_device_name ( const gchar *mount_point, gchar **device_name)
+gint gw_dm_disk_get_device_name ( const gchar *mount_point, gchar **device_name)
 {
 	gint result = -1;
 
 
 #ifdef GW_DEBUG_MODE
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
 #endif
 
 	if ( mount_point != NULL )
@@ -719,7 +698,7 @@ gint gw_device_manager_disk_get_device_name ( const gchar *mount_point, gchar **
 }
 
 
-gboolean gw_device_manager_disk_is_mounted_from_vfs_stats ( struct vfs_stats *p)
+gboolean gw_dm_disk_is_mounted_from_vfs_stats ( struct vfs_stats *p)
 {
 	/* This function checks if the file system is already mounted. */
 	gboolean success = FALSE;
@@ -729,7 +708,7 @@ gboolean gw_device_manager_disk_is_mounted_from_vfs_stats ( struct vfs_stats *p)
 
 
 #ifdef GW_DEBUG_DATA_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
 #endif
 
 	if ( p != NULL )
@@ -737,22 +716,19 @@ gboolean gw_device_manager_disk_is_mounted_from_vfs_stats ( struct vfs_stats *p)
 #if defined ( OS_LINUX) || defined ( OS_FREEBSD) || defined ( OS_OPENBSD) || defined ( OS_NETBSD) || defined ( OS_MACOS) || defined ( OS_MACOSX) || defined ( OS_DARWIN)
 		type = vfs_stats_get_type ( p);
 
-		/* If the supermount is activated under Mandrake system, a mount test is needed. */
-		if ( (type != NULL) && (strncmp ( type, "supermount", 10) == 0) )
-		{
+		/* If the supermount is activated under Mandrake system or submount is activated under SuSe,
+		   a mount test is needed. */
+		if ( (type != NULL) && ((strncmp ( type, "supermount", 10) == 0) || (strncmp ( type, "subfs", 5) == 0)) ) {
 			/* If the device is in supermount mode, try to acces it */
-
-			success = gw_device_manager_disk_try_mount_from_vfs_stats ( p);
-//			success = gw_device_disk_in_drive ( vfs_stats_get_dir ( p));
-		}
-		else
-		{
+			success = gw_dm_disk_try_mount_from_vfs_stats ( p);
+//			success = gw_dm_is_disk_in_drive ( vfs_stats_get_dir ( p));
+		} else {
 			/* Returns the mount state */
 
 			success = vfs_stats_get_ismounted ( p);
 		}
 #elif defined ( OS_WIN32) || defined ( OS_CYGWIN)
-		success = gw_device_disk_in_drive ( vfs_stats_get_dir ( p));
+		success = gw_dm_is_disk_in_drive ( vfs_stats_get_dir ( p));
 #endif
 	}
 
@@ -760,13 +736,13 @@ gboolean gw_device_manager_disk_is_mounted_from_vfs_stats ( struct vfs_stats *p)
 }
 
 
-gboolean gw_device_manager_disk_can_mounted_from_vfs_stats ( struct vfs_stats *p)
+gboolean gw_dm_disk_can_mounted_from_vfs_stats ( struct vfs_stats *p)
 {
 	/* This function checks if a file system can be mounted,
 	   without mount it.
 	*/
 #ifdef GW_DEBUG_DATA_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
 #endif
 
 	if ( p != NULL )
@@ -777,7 +753,7 @@ gboolean gw_device_manager_disk_can_mounted_from_vfs_stats ( struct vfs_stats *p
 		}
 		else
 		{
-			return gw_device_manager_disk_try_mount_from_vfs_stats ( p);
+			return gw_dm_disk_try_mount_from_vfs_stats ( p);
 		}
 	}
 
@@ -785,7 +761,7 @@ gboolean gw_device_manager_disk_can_mounted_from_vfs_stats ( struct vfs_stats *p
 }
 
 
-gboolean gw_device_disk_in_drive ( const gchar *drive_path)
+gboolean gw_dm_is_disk_in_drive ( const gchar *drive_path)
 {
 	/* This function checks if there is a disk in the drive
 	   designed by the full path name (stored in the parameter
@@ -806,7 +782,7 @@ gboolean gw_device_disk_in_drive ( const gchar *drive_path)
 
 
 #ifdef GW_DEBUG_DATA_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
 #endif
 
 	if ( drive_path != NULL )
@@ -881,7 +857,7 @@ gboolean gw_device_disk_in_drive ( const gchar *drive_path)
 	}
 
 #ifdef GW_DEBUG_DATA_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "%s is %savailable", drive_path,result?"":"un");
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "%s is %savailable", drive_path,result?"":"un");
 #endif
 
 	return result;
