@@ -17,6 +17,7 @@
  */
 
 
+#include <string.h> /* strlen */
 #include "gwsupport.h"
 #include "gwguimanager.h"
 
@@ -32,8 +33,7 @@ GtkWindow *window;
 GtkCTreeNode *root;
 
 
-GtkWindow * gw_gui_manager_main_interface_create ( )
-{
+GtkWindow * gw_gui_manager_main_interface_create ( ) {
 	GtkWidget *main_window = NULL;
 	GtkWidget *vbox = NULL;
 	GtkWidget *menu_bar = NULL;
@@ -48,7 +48,7 @@ GtkWindow * gw_gui_manager_main_interface_create ( )
 
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
 #endif
 
 	accel_group = gtk_accel_group_new ( );
@@ -59,32 +59,27 @@ GtkWindow * gw_gui_manager_main_interface_create ( )
 	gtk_window_set_policy ( window, TRUE, TRUE, FALSE);
 
 	/* Checks if have last size and cheks if the window can be displayed in the current screen. */
-	if ( (height = gw_application_manager_get_settings_tol ( GW_VALUE_APP_WIN_HEIGHT)) < 0 )
-	{
+	if ( (height = gw_am_get_settings_tol ( GW_VALUE_APP_WIN_HEIGHT)) < 0 ) {
 		height = GW_VALUE_APP_WIN_HEIGHT_DEFAULT;
 	}
 	height = MIN ( height, gdk_screen_height ( ));
 
-	if ( (width = gw_application_manager_get_settings_tol ( GW_VALUE_APP_WIN_WIDTH)) < 0 )
-	{
+	if ( (width = gw_am_get_settings_tol ( GW_VALUE_APP_WIN_WIDTH)) < 0 ) {
 		width = GW_VALUE_APP_WIN_WIDTH_DEFAULT;
 	}
 	width = MIN ( width, gdk_screen_width ( ));
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "window size is %dx%d", width, height);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "window size is %dx%d", width, height);
 #endif
 
 	/* It is better to use gtk_widget_set_usize() or gtk_window_set_default_size()? */
 	gtk_window_set_default_size ( GTK_WINDOW ( main_window), width, height);
 
 	/* Checks if have lasty position and checks if the window can be displayed in the current screen. */
-	if ( ((x = gw_application_manager_get_settings_tol ( GW_VALUE_APP_WIN_X)) >= 0) && ((y = gw_application_manager_get_settings_tol ( GW_VALUE_APP_WIN_Y)) >= 0) )
-	{
+	if ( ((x = gw_am_get_settings_tol ( GW_VALUE_APP_WIN_X)) >= 0) && ((y = gw_am_get_settings_tol ( GW_VALUE_APP_WIN_Y)) >= 0) ) {
 		 gtk_widget_set_uposition ( main_window, x, y);
-	}
-	else
-	{
+	} else {
 		gtk_window_set_position ( GTK_WINDOW ( main_window), GTK_WIN_POS_CENTER);
 	}
 
@@ -121,18 +116,16 @@ GtkWindow * gw_gui_manager_main_interface_create ( )
 }
 
 
-gint gw_gui_manager_main_interface_set_tree_root ( GtkCTreeNode *node)
-{
+gint gw_gui_manager_main_interface_set_tree_root ( GtkCTreeNode *node) {
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
 #endif
 
 	root = node;
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	if ( root == NULL )
-	{
-		gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "root node is NULL");
+	if ( root == NULL ) {
+		gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "root node is NULL");
 	}
 #endif
 
@@ -141,16 +134,14 @@ gint gw_gui_manager_main_interface_set_tree_root ( GtkCTreeNode *node)
 
 
 
-GtkWindow * gw_gui_manager_main_interface_get_main_window ( void)
-{
+GtkWindow * gw_gui_manager_main_interface_get_main_window ( void) {
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
 #endif
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	if ( window == NULL )
-	{
-		gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "main window is NULL");
+	if ( window == NULL ) {
+		gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "main window is NULL");
 	}
 #endif
 
@@ -158,21 +149,19 @@ GtkWindow * gw_gui_manager_main_interface_get_main_window ( void)
 }
 
 
-GtkWindow * gw_gui_manager_main_interface_get_progress_bar_box ( void)
-{
+GtkWindow * gw_gui_manager_main_interface_get_progress_bar_box ( void) {
 	GtkWindow *progress_bar_box = NULL;
 
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
 #endif
 
 	progress_bar_box = gtk_object_get_data ( GTK_OBJECT ( window), GW_REF_PROGRESS_BAR_BOX);
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	if ( progress_bar_box == NULL )
-	{
-		gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "progress bar box is NULL");
+	if ( progress_bar_box == NULL ) {
+		gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "progress bar box is NULL");
 	}
 #endif
 
@@ -180,21 +169,19 @@ GtkWindow * gw_gui_manager_main_interface_get_progress_bar_box ( void)
 }
 
 
-GtkCTree * gw_gui_manager_main_interface_get_tree ( void)
-{
+GtkCTree * gw_gui_manager_main_interface_get_tree ( void) {
 	GtkCTree *tree = NULL;
 
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
 #endif
 
 	tree = GTK_CTREE ( gtk_object_get_data ( GTK_OBJECT ( window), GW_REF_TREE));
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	if ( tree == NULL )
-	{
-		gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "tree is NULL");
+	if ( tree == NULL ) {
+		gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "tree is NULL");
 	}
 #endif
 
@@ -202,16 +189,14 @@ GtkCTree * gw_gui_manager_main_interface_get_tree ( void)
 }
 
 
-GtkCTreeNode * gw_gui_manager_main_interface_get_tree_root ( void)
-{
+GtkCTreeNode * gw_gui_manager_main_interface_get_tree_root ( void) {
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
 #endif
 
-	if ( root == NULL )
-	{
+	if ( root == NULL ) {
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-		gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "root node is NULL");
+		gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "root node is NULL");
 #endif
 	}
 
@@ -219,54 +204,51 @@ GtkCTreeNode * gw_gui_manager_main_interface_get_tree_root ( void)
 }
 
 
-void gw_gui_manager_main_interface_refresh ( void)
-{
+void gw_gui_manager_main_interface_refresh ( void) {
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
 #endif
 
-	while ( gtk_events_pending ( ) )
-	{
+	while ( gtk_events_pending ( ) ) {
 		gtk_main_iteration ( );
 	}
 }
 
 
-void gw_gui_manager_main_interface_update_all ( void)
-{
+void gw_gui_manager_main_interface_update_all ( void) {
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
 #endif
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "refreshing categories...");
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "refreshing categories...");
 #endif
 
 	gw_notebook_managment_refresh_categories ( window);
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "updating menus...");
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "updating menus...");
 #endif
 
 	gw_gui_manager_main_interface_update_menus ( );
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "updating devices informations....");
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "updating devices informations....");
 #endif
 
 	gw_gui_manager_main_interface_update_notebook_catalog ( );
+
 	gw_gui_manager_main_interface_update_notebook_search ( );
+
 	gw_gui_manager_main_interface_update_notebook_managment ( );
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "all updates and refresh are done!!");
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "all updates and refresh are done!!");
 #endif
-
 }
 
 
-void gw_gui_manager_main_interface_update_menus ( void)
-{
+void gw_gui_manager_main_interface_update_menus ( void) {
 	gchar *files = NULL;
 	gchar **files_list = NULL;
 	gint i = 0, size = 0;
@@ -274,13 +256,11 @@ void gw_gui_manager_main_interface_update_menus ( void)
 
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
 #endif
 
-	if ( (files = gw_application_manager_get_settings ( GW_VALUE_APP_RECENTS_FILES)) != NULL)
-	{
-		if ( (max_nb_files = gw_application_manager_get_settings_tol ( GW_VALUE_APP_RECENT_SIZE)) == -1 )
-		{
+	if ( (files = gw_am_get_settings ( GW_VALUE_APP_RECENTS_FILES)) != NULL) {
+		if ( (max_nb_files = gw_am_get_settings_tol ( GW_VALUE_APP_RECENT_SIZE)) == -1 ) {
 			max_nb_files = GW_VALUE_APP_RECENT_SIZE_DEFAULT;
 		}
 
@@ -288,33 +268,26 @@ void gw_gui_manager_main_interface_update_menus ( void)
 
 
 		/* Gets the number of recents opened files. */
-		for ( i = 0; files_list[i] != NULL; i++)
-		{
-		}
+		for ( i = 0; files_list[i] != NULL; i++) { }
 
 		size = i;
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-		gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "Current history size is %d", size);
+		gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "Current history size is %d", size);
 #endif
 
-		if ( size > 0 )
-		{
+		if ( size > 0 ) {
 			/* Removes all unwanted items (all over the max size). */
-			if ( size > max_nb_files )
-			{
-				for ( i = max_nb_files; files_list[i] != NULL; i++)
-				{
+			if ( size > max_nb_files ) {
+				for ( i = max_nb_files; files_list[i] != NULL; i++) {
 					g_free ( files_list[i]);
 					files_list[i] = NULL;
 				}
 			}
 
 			/* Removes the last item if is empty (for the case where the list is ended by ";"). */
-			if ( files_list[size - 1] != NULL )
-			{
-				if ( strlen ( files_list[size - 1]) == 0 )
-				{
+			if ( files_list[size - 1] != NULL ) {
+				if ( strlen ( files_list[size - 1]) == 0 ) {
 					g_free ( files_list[size - 1]);
 					files_list[size - 1] = NULL;
 				}
@@ -327,251 +300,225 @@ void gw_gui_manager_main_interface_update_menus ( void)
 }
 
 
-void gw_gui_manager_main_interface_update_notebook_catalog ( void)
-{
+void gw_gui_manager_main_interface_update_notebook_catalog ( void) {
 	GtkCTree *tree = NULL;
 	GtkCTreeNode *selection = NULL;
 
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
 #endif
 
-	if ( (tree = gw_gui_manager_main_interface_get_tree ( )) != NULL )
-	{
-		if ( (GTK_CLIST ( tree)->selection != NULL) && ((selection = GTK_CTREE_NODE ( GTK_CLIST ( tree)->selection->data)) != NULL) )
-		{
+	if ( (tree = gw_gui_manager_main_interface_get_tree ( )) != NULL ) {
+		if ( (GTK_CLIST ( tree)->selection != NULL) && ((selection = GTK_CTREE_NODE ( GTK_CLIST ( tree)->selection->data)) != NULL) ) {
 			gtk_ctree_select ( GTK_CTREE ( tree), selection);
-		}
-		else
-		{
+		} else {
 			gw_notebook_catalog_clist_explorer_set_column_title_disk ( );
 		}
-	}
-	else
-	{
+	} else {
 		gw_notebook_catalog_clist_explorer_set_column_title_disk ( );
 	}
 
 	return;
 }
 
-void gw_gui_manager_main_interface_update_notebook_search ( void)
-{
+void gw_gui_manager_main_interface_update_notebook_search ( void) {
 	gint value = 0;
 	gchar *str = NULL;
 
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
 #endif
 
-	str = gw_application_manager_get_settings ( GW_VALUE_APP_SEARCH_STRING);
+	str = gw_am_get_settings ( GW_VALUE_APP_SEARCH_STRING);
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "search string => %s", str);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "search string => %s", str);
 #endif
 
 	gw_notebook_search_set_search_text ( gw_gui_manager_main_interface_get_main_window ( ), str);
 
-	if ( (value = gw_application_manager_get_settings_tol ( GW_VALUE_APP_SEARCH_CASE_SENSITIVE)) == -1 )
-	{
+	if ( (value = gw_am_get_settings_tol ( GW_VALUE_APP_SEARCH_CASE_SENSITIVE)) == -1 ) {
 		value = GW_VALUE_APP_SEARCH_CASE_SENSITIVE_DEFAULT;
 	}
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "use case sensitive => %d", value);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "use case sensitive => %d", value);
 #endif
 
 	gw_notebook_search_set_option_case_sensitive ( gw_gui_manager_main_interface_get_main_window ( ), value);
 
-	if ( (value = gw_application_manager_get_settings_tol ( GW_VALUE_APP_SEARCH_TYPE)) == -1 )
-	{
+	if ( (value = gw_am_get_settings_tol ( GW_VALUE_APP_SEARCH_TYPE)) == -1 ) {
 		value = GW_VALUE_APP_SEARCH_TYPE_DEFAULT;
 	}
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "search type => %d", value);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "search type => %d", value);
 #endif
 
 	gw_notebook_search_set_option_search_type ( gw_gui_manager_main_interface_get_main_window ( ), value);
 
-	if ( (value = gw_application_manager_get_settings_tol ( GW_VALUE_APP_SEARCH_FILE_NAME)) == -1 )
-	{
+	if ( (value = gw_am_get_settings_tol ( GW_VALUE_APP_SEARCH_FILE_NAME)) == -1 ) {
 		value = GW_VALUE_APP_SEARCH_FILE_NAME_DEFAULT;
 	}
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "match with files name => %d", value);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "match with files name => %d", value);
 #endif
 
 	gw_notebook_search_set_option_match_file ( gw_gui_manager_main_interface_get_main_window ( ), value);
 
-	if ( (value = gw_application_manager_get_settings_tol ( GW_VALUE_APP_SEARCH_FOLDER_NAME)) == -1 )
-	{
+	if ( (value = gw_am_get_settings_tol ( GW_VALUE_APP_SEARCH_FOLDER_NAME)) == -1 ) {
 		value = GW_VALUE_APP_SEARCH_FOLDER_NAME_DEFAULT;
 	}
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "match with folders name => %d", value);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "match with folders name => %d", value);
 #endif
 
 	gw_notebook_search_set_option_match_folder ( gw_gui_manager_main_interface_get_main_window ( ), value);
 
-	if ( (value = gw_application_manager_get_settings_tol ( GW_VALUE_APP_SEARCH_DISK_NAME)) == -1 )
-	{
+	if ( (value = gw_am_get_settings_tol ( GW_VALUE_APP_SEARCH_DISK_NAME)) == -1 ) {
 		value = GW_VALUE_APP_SEARCH_DISK_NAME_DEFAULT;
 	}
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "match with disks name => %d", value);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "match with disks name => %d", value);
 #endif
 
 	gw_notebook_search_set_option_match_disk ( gw_gui_manager_main_interface_get_main_window ( ), value);
 
-	if ( (value = gw_application_manager_get_settings_tol ( GW_VALUE_APP_SEARCH_CATEGORY_NAME)) == -1 )
-	{
+	if ( (value = gw_am_get_settings_tol ( GW_VALUE_APP_SEARCH_CATEGORY_NAME)) == -1 ) {
 		value = GW_VALUE_APP_SEARCH_CATEGORY_NAME_DEFAULT;
 	}
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "math woth categories name => %d", value);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "math woth categories name => %d", value);
 #endif
 
 	gw_notebook_search_set_option_match_category ( gw_gui_manager_main_interface_get_main_window ( ), value);
 
-	if ( (value = gw_application_manager_get_settings_tol ( GW_VALUE_APP_SEARCH_DESCRIPTION)) == -1 )
-	{
+	if ( (value = gw_am_get_settings_tol ( GW_VALUE_APP_SEARCH_DESCRIPTION)) == -1 ) {
 		value = GW_VALUE_APP_SEARCH_DESCRIPTION_DEFAULT;
 	}
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "use case sensitive => %d", value);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "use case sensitive => %d", value);
 #endif
 
 	gw_notebook_search_set_option_match_description ( gw_gui_manager_main_interface_get_main_window ( ), value);
-	
-	
+
+
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "updating the search column properties");
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "updating the search column properties");
 #endif
 
 	gw_notebook_search_clist_search_set_column_title ( );
 }
 
 
-void gw_gui_manager_main_interface_update_notebook_managment ( void)
-{
+void gw_gui_manager_main_interface_update_notebook_managment ( void) {
 	gint value = 0;
 
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
 #endif
 
-	if ( (value = gw_application_manager_get_settings_tol ( GW_VALUE_APP_DISK_DISPLAY_INFO)) == -1 )
-	{
-	value = GW_VALUE_APP_DISK_DISPLAY_INFO_DEFAULT;
+	if ( (value = gw_am_get_settings_tol ( GW_VALUE_APP_DISK_DISPLAY_INFO)) == -1 ) {
+		value = GW_VALUE_APP_DISK_DISPLAY_INFO_DEFAULT;
 	}
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "display info => %d", value);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "display info => %d", value);
 #endif
 
 	gw_notebook_managment_set_option_display_info ( gw_gui_manager_main_interface_get_main_window ( ), value);
 
-	if ( (value = gw_application_manager_get_settings_tol ( GW_VALUE_APP_DISK_SCAN_EXPLORE_TREE_STRUCTURE)) == -1 )
-	{
+	if ( (value = gw_am_get_settings_tol ( GW_VALUE_APP_DISK_SCAN_EXPLORE_TREE_STRUCTURE)) == -1 ) {
 		value = GW_VALUE_APP_DISK_SCAN_EXPLORE_TREE_STRUCTURE_DEFAULT;
 	}
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "explore tree structure => %d", value);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "explore tree structure => %d", value);
 #endif
 
 	gw_notebook_managment_set_option_explore_tree_structure ( gw_gui_manager_main_interface_get_main_window ( ), value);
 
-	if ( (value = gw_application_manager_get_settings_tol ( GW_VALUE_APP_DISK_SCAN_EXPLORE_ARCHIVE)) == -1 )
-	{
-	value = GW_VALUE_APP_DISK_SCAN_EXPLORE_ARCHIVE_DEFAULT;
+	if ( (value = gw_am_get_settings_tol ( GW_VALUE_APP_DISK_SCAN_EXPLORE_ARCHIVE)) == -1 ) {
+		value = GW_VALUE_APP_DISK_SCAN_EXPLORE_ARCHIVE_DEFAULT;
 	}
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "explore archive => %d", value);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "explore archive => %d", value);
 #endif
 
 	gw_notebook_managment_set_option_explore_archive ( gw_gui_manager_main_interface_get_main_window ( ), value);
 
-	if ( (value = gw_application_manager_get_settings_tol ( GW_VALUE_APP_DISK_SCAN_CATEGORY)) ==  -1)
-	{
-	value = GW_VALUE_APP_DISK_SCAN_CATEGORY_DEFAULT;
+	if ( (value = gw_am_get_settings_tol ( GW_VALUE_APP_DISK_SCAN_CATEGORY)) ==  -1) {
+		value = GW_VALUE_APP_DISK_SCAN_CATEGORY_DEFAULT;
 	}
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "category recursive => %d", value);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "category recursive => %d", value);
 #endif
 
 	gw_notebook_managment_set_option_category_recursive ( gw_gui_manager_main_interface_get_main_window ( ), value);
 
-	if ( (value = gw_application_manager_get_settings_tol ( GW_VALUE_APP_DISK_SCAN_DESCRIPTION)) == -1 )
-	{
-	value = GW_VALUE_APP_DISK_SCAN_DESCRIPTION_DEFAULT;
+	if ( (value = gw_am_get_settings_tol ( GW_VALUE_APP_DISK_SCAN_DESCRIPTION)) == -1 ) {
+		value = GW_VALUE_APP_DISK_SCAN_DESCRIPTION_DEFAULT;
 	}
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "make description => %d", value);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "make description => %d", value);
 #endif
 
 	gw_notebook_managment_set_option_make_description ( gw_gui_manager_main_interface_get_main_window ( ), value);
 
-	if ( (value = gw_application_manager_get_settings_tol ( GW_VALUE_APP_DISK_SCAN_USE_PATTERN)) == -1 )
-	{
+	if ( (value = gw_am_get_settings_tol ( GW_VALUE_APP_DISK_SCAN_USE_PATTERN)) == -1 ) {
 		value = GW_VALUE_APP_DISK_SCAN_USE_PATTERN_DEFAULT;
 	}
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "use pattern => %d", value);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "use pattern => %d", value);
 #endif
 
 	gw_notebook_managment_set_option_use_pattern ( gw_gui_manager_main_interface_get_main_window ( ), value);
 
-	if ( (value = gw_application_manager_get_settings_tol ( GW_VALUE_APP_DISK_SCAN_LABEL)) == -1 )
-	{
+	if ( (value = gw_am_get_settings_tol ( GW_VALUE_APP_DISK_SCAN_LABEL)) == -1 ) {
 		value = GW_VALUE_APP_DISK_SCAN_LABEL_DEFAULT;
 	}
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "use volume name => %d", value);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "use volume name => %d", value);
 #endif
 
 	gw_notebook_managment_set_option_use_disk_label ( gw_gui_manager_main_interface_get_main_window ( ), value);
 
-	if ( (value = gw_application_manager_get_settings_tol ( GW_VALUE_APP_DISK_AUTOMOUNT)) == -1 )
-	{
-	value = GW_VALUE_APP_DISK_AUTOMOUNT_DEFAULT;
+	if ( (value = gw_am_get_settings_tol ( GW_VALUE_APP_DISK_AUTOMOUNT)) == -1 ) {
+		value = GW_VALUE_APP_DISK_AUTOMOUNT_DEFAULT;
 	}
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "automount => %d", value);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "automount => %d", value);
 #endif
 
 	gw_notebook_managment_set_option_automount ( gw_gui_manager_main_interface_get_main_window ( ), value);
 
-	if ( (value = gw_application_manager_get_settings_tol ( GW_VALUE_APP_DISK_EJECT)) == -1 )
-	{
-	value = GW_VALUE_APP_DISK_EJECT_DEFAULT;
+	if ( (value = gw_am_get_settings_tol ( GW_VALUE_APP_DISK_EJECT)) == -1 ) {
+		value = GW_VALUE_APP_DISK_EJECT_DEFAULT;
 	}
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "eject => %d", value);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, "eject => %d", value);
 #endif
 
 	gw_notebook_managment_set_option_eject ( gw_gui_manager_main_interface_get_main_window ( ), value);
 }
 
 
-void gw_gui_manager_exit ( void)
-{
+void gw_gui_manager_exit ( void) {
 	GtkWindow *window = NULL;
 	gchar *selected_device = NULL;
 	gint x, y, width, height;
@@ -579,36 +526,32 @@ void gw_gui_manager_exit ( void)
 
 
 #ifdef GW_DEBUG_GUI_CALLBACK_COMPONENT
-	gw_application_manager_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
+	gw_am_log_msg ( 0, __FILE__, __LINE__, __PRETTY_FUNCTION__, NULL);
 #endif
 
 	window = gw_gui_manager_main_interface_get_main_window ( );
 
-	if ( window != NULL )
-	{
+	if ( window != NULL ) {
 		/* Saves the horizontal pane position which is in the catalog tabbed pane. */
-		if ( (position = gw_notebook_catalog_get_hpan_position ( window)) != -1 )
-		{
-			gw_application_manager_set_settings ( GW_VALUE_APP_EXPLORER_HPAN_POSITION, g_strdup_printf ( "%d", position));
+		if ( (position = gw_notebook_catalog_get_hpan_position ( window)) != -1 ) {
+			gw_am_set_settings ( GW_VALUE_APP_EXPLORER_HPAN_POSITION, g_strdup_printf ( "%d", position));
 		}
 
 		/* Saves the last selected device. */
 		selected_device = gw_notebook_managment_get_device_dir ( window);
 
-		if ( selected_device != NULL )
-		{
-			gw_application_manager_set_settings ( GW_VALUE_APP_DISK_SELECTED, selected_device);
+		if ( selected_device != NULL ) {
+			gw_am_set_settings ( GW_VALUE_APP_DISK_SELECTED, selected_device);
 		}
 
 		/* Saves the main window size and position. */
-		if ( gw_application_manager_get_settings_tol ( GW_VALUE_APP_GUI_AUTOSAVE) == 1 )
-		{
+		if ( gw_am_get_settings_tol ( GW_VALUE_APP_GUI_AUTOSAVE) == 1 ) {
 			gdk_window_get_position ( GTK_WIDGET ( window)->window, &x, &y);
 			gdk_window_get_size ( GTK_WIDGET ( window)->window, &width, &height);
-			gw_application_manager_set_settings ( GW_VALUE_APP_WIN_X, g_strdup_printf ( "%d", x));
-			gw_application_manager_set_settings ( GW_VALUE_APP_WIN_Y, g_strdup_printf ( "%d", y));
-			gw_application_manager_set_settings ( GW_VALUE_APP_WIN_WIDTH, g_strdup_printf ( "%d", width));
-			gw_application_manager_set_settings ( GW_VALUE_APP_WIN_HEIGHT, g_strdup_printf ( "%d", height));
+			gw_am_set_settings ( GW_VALUE_APP_WIN_X, g_strdup_printf ( "%d", x));
+			gw_am_set_settings ( GW_VALUE_APP_WIN_Y, g_strdup_printf ( "%d", y));
+			gw_am_set_settings ( GW_VALUE_APP_WIN_WIDTH, g_strdup_printf ( "%d", width));
+			gw_am_set_settings ( GW_VALUE_APP_WIN_HEIGHT, g_strdup_printf ( "%d", height));
 		}
 
 		/* Destroyes the main window. */
