@@ -321,8 +321,7 @@ GList * gw_get_drives_list ( GList *g)
 }
 
 
-gboolean gw_drive_eject ( const gchar *drive_path)
-{
+gboolean gw_drive_eject ( const gchar *drive_path) {
 	gboolean l_result = FALSE;
 #if defined ( HAVE_MOUNT_SYSTEM) && !defined (OS_FREEBSD) && !defined (OS_OPENBSD) && !defined (OS_NETBSD) && !defined ( OS_MACOS) && !defined ( OS_MACOSX) && !defined ( OS_DARWIN)
 	FILE *fstab = NULL;
@@ -336,32 +335,26 @@ gboolean gw_drive_eject ( const gchar *drive_path)
 #endif
 
 	/* Opens the /etc/fstab file. */
-	if ( (fstab = setmntent ( "/etc/fstab", "r")) != NULL )
-	{
-		while ( (pm = getmntent ( fstab)) != NULL)
-		{
-			if ( (pm->mnt_dir != NULL) && (strcmp ( pm->mnt_dir, drive_path) == 0) )
-			{
+	if ( (fstab = setmntent ( "/etc/fstab", "r")) != NULL ) {
+		while ( (pm = getmntent ( fstab)) != NULL) {
+			if ( (pm->mnt_dir != NULL) && (strcmp ( pm->mnt_dir, drive_path) == 0) ) {
 				/* Search the type of mount. */
-				if ( (pm->mnt_type != NULL) && (strcmp ( pm->mnt_type,"supermount") == 0) )
-				{
+//				if ( (pm->mnt_type != NULL) && ((strcmp ( pm->mnt_type,"supermount") == 0)||(strcmp ( pm->mnt_type,"subfs") == 0)) ) {
+				if ( (pm->mnt_type != NULL) && (strcmp ( pm->mnt_type,"supermount") == 0) ) {
 					/* Gets the name of the device. */
 					char *temp;
+					//FIXME memory leak ?
 					temp = strtok ( hasmntopt ( pm, "dev"), "=");
 					temp = strtok ( NULL, "=");
 
-					if ( temp )
-					{
+					if ( temp ) {
 						fd = open ( temp, O_RDONLY|O_NONBLOCK );
 					}
-				}
-				else
-				{
+				} else {
 					fd = open ( pm->mnt_fsname, O_RDONLY|O_NONBLOCK );
 				}
 
-				if ( fd >= 0 )
-				{
+				if ( fd >= 0 ) {
 #if defined ( OS_FREEBSD_DEPRECATED) || defined ( OS_OPENBSD_DEPRECATED) || defined ( OS_NETBSD_DEPRECATED) || defined ( OS_MACOS) || defined ( OS_MACOSX) || defined ( OS_DARWIN)
 					ioctl ( fd, CDIOCALLOW);
 #endif
@@ -390,14 +383,11 @@ gboolean gw_drive_eject ( const gchar *drive_path)
 	/* Opens the /etc/fstab file. */
 	setfsent ( );
 
-	while ( (partition = getfsent ( )) != NULL )
-	{
-		if ( (partition->fs_file != NULL) && (strcmp ( partition->fs_file, drive_path) == 0) )
-		{
+	while ( (partition = getfsent ( )) != NULL ) {
+		if ( (partition->fs_file != NULL) && (strcmp ( partition->fs_file, drive_path) == 0) ) {
 			fd = open ( partition->fs_spec, O_RDONLY );
 
-			if ( fd >= 0 )
-			{
+			if ( fd >= 0 ) {
 				status = ioctl ( fd, CDIOCEJECT);
 
 				close ( fd);
@@ -429,32 +419,27 @@ gboolean gw_drive_eject ( const gchar *drive_path)
 	g_print ( "*** GW - %s (%d) :: %s() : drive=%s\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, drive_path);
 #endif
 
-	if ( drive_path != NULL )
-	{
+	if ( drive_path != NULL ) {
 		errmode = SetErrorMode ( SEM_FAILCRITICALERRORS);
 
 		/* Win2K ejection code */
-		if ( GetVersion() < 0x80000000 )
-		{
+		if ( GetVersion() < 0x80000000 ) {
 #ifdef GW_DEBUG_MODE
 			g_print ( "*** GW - %s (%d) :: %s() : using NT kernel API\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
 #endif
 
 		/* I don't know with but the drive letter has to be passed without a trailing slash (ie "\\.\C:" instead of "\\.\C:\"). */
 		device_name = g_strdup_printf ( "\\\\.\\%s", drive_path);
-		if ( device_name[strlen(device_name)-1] == '\\')
-		{
+		if ( device_name[strlen(device_name)-1] == '\\') {
 			device_name[strlen(device_name)-1] = '\0';
 		}
 
-		if ( (hdl_file = CreateFile ( (char *)device_name, GENERIC_READ, FILE_SHARE_READ | FILE_SHARE_WRITE, NULL, OPEN_EXISTING, 0, NULL)) != NULL )
-		/*if ( (hdl_file = CreateFile ( (char *)device_name, GENERIC_READ, 0 , NULL, OPEN_EXISTING, FILE_FLAG_RANDOM_ACCESS, NULL)) != NULL )*/
-		{
+		if ( (hdl_file = CreateFile ( (char *)device_name, GENERIC_READ, FILE_SHARE_READ | FILE_SHARE_WRITE, NULL, OPEN_EXISTING, 0, NULL)) != NULL ) {
+		/*if ( (hdl_file = CreateFile ( (char *)device_name, GENERIC_READ, 0 , NULL, OPEN_EXISTING, FILE_FLAG_RANDOM_ACCESS, NULL)) != NULL ) {*/
 			l_result = DeviceIoControl ( hdl_file, IOCTL_STORAGE_EJECT_MEDIA, NULL, 0, NULL, 0, &lp_bytes_returned, NULL);
 
 #ifdef GW_DEBUG_TOOLS_COMPONENT
-				if ( l_result == FALSE )
-				{
+				if ( l_result == FALSE ) {
 					FormatMessage ( FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM | FORMAT_MESSAGE_IGNORE_INSERTS, NULL, GetLastError ( ), 0, (LPTSTR) &msg, 0, NULL );
 					g_print ( "*** GW - %s (%d) :: %s() : an win32 error occured, %s (%d)\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, msg, GetLastError ( ));
 					LocalFree( msg );
@@ -462,50 +447,43 @@ gboolean gw_drive_eject ( const gchar *drive_path)
 #endif
 
 			CloseHandle ( hdl_file);
-		}
-			else
-			{
+		} else {
 #ifdef GW_DEBUG_TOOLS_COMPONENT
+			FormatMessage ( FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM | FORMAT_MESSAGE_IGNORE_INSERTS, NULL, GetLastError ( ), 0, (LPTSTR) &msg, 0, NULL );
+			g_print ( "*** GW - %s (%d) :: %s() : an win32 error occured, %s (%d)\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, msg, GetLastError ( ));
+			LocalFree( msg );
+#endif
+		}
+
+		g_free ( device_name);
+	} else {
+		/* Win95/98/ME */
+#ifdef GW_DEBUG_MODE
+		g_print ( "*** GW - %s (%d) :: %s() : using Win9x kernel API\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
+#endif
+
+		/* Create the handle to VWIN32 */
+		if ( (hdl_file = CreateFile ( "\\\\.\\vwin32", 0, 0, NULL, 0, FILE_FLAG_DELETE_ON_CLOSE, NULL)) != NULL ) {
+			/* Convert logical disk name to DOS-like disk name */
+			by_drive = (toupper ( *drive_path) - 'A') + 1;
+
+			/* Let's eject now : Int 21H function 440DH minor code 49h */
+			regs.reg_EAX = 0x440D;
+			regs.reg_EBX = by_drive;
+			regs.reg_ECX = MAKEWORD ( 0x49, 0x08);	/* minor code */
+
+			l_result = DeviceIoControl ( hdl_file, VWIN32_DIOC_DOS_IOCTL, &regs, sizeof ( regs), &regs, sizeof ( regs), &dw_result, 0);
+
+#ifdef GW_DEBUG
+			if ( l_result == FALSE ) {
 				FormatMessage ( FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM | FORMAT_MESSAGE_IGNORE_INSERTS, NULL, GetLastError ( ), 0, (LPTSTR) &msg, 0, NULL );
 				g_print ( "*** GW - %s (%d) :: %s() : an win32 error occured, %s (%d)\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, msg, GetLastError ( ));
 				LocalFree( msg );
-#endif
 			}
-
-		g_free ( device_name);
-	}
-		else       /* Win95/98/ME */
-		{
-#ifdef GW_DEBUG_MODE
-			g_print ( "*** GW - %s (%d) :: %s() : using Win9x kernel API\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
-#endif
-
-			/* Create the handle to VWIN32 */
-			if ( (hdl_file = CreateFile ( "\\\\.\\vwin32", 0, 0, NULL, 0, FILE_FLAG_DELETE_ON_CLOSE, NULL)) != NULL )
-			{
-				/* Convert logical disk name to DOS-like disk name */
-				by_drive = (toupper ( *drive_path) - 'A') + 1;
-
-				/* Let's eject now : Int 21H function 440DH minor code 49h */
-				regs.reg_EAX = 0x440D;
-				regs.reg_EBX = by_drive;
-				regs.reg_ECX = MAKEWORD ( 0x49, 0x08);	/* minor code */
-
-				l_result = DeviceIoControl ( hdl_file, VWIN32_DIOC_DOS_IOCTL, &regs, sizeof ( regs), &regs, sizeof ( regs), &dw_result, 0);
-
-#ifdef GW_DEBUG
-				if ( l_result == FALSE )
-				{
-					FormatMessage ( FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM | FORMAT_MESSAGE_IGNORE_INSERTS, NULL, GetLastError ( ), 0, (LPTSTR) &msg, 0, NULL );
-					g_print ( "*** GW - %s (%d) :: %s() : an win32 error occured, %s (%d)\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, msg, GetLastError ( ));
-					LocalFree( msg );
-				}
 #endif
 
 				CloseHandle ( hdl_file) ;
-			}
-			else
-			{
+			} else {
 #ifdef GW_DEBUG
 				FormatMessage ( FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM | FORMAT_MESSAGE_IGNORE_INSERTS, NULL, GetLastError ( ), 0, (LPTSTR) &msg, 0, NULL );
 				g_print ( "*** GW - %s (%d) :: %s() : an win32 error occured, %s (%d)\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, msg, GetLastError ( ));
@@ -868,8 +846,7 @@ gboolean gw_drive_umount ( const gchar *drive_path)
 }
 
 
-gchar * gw_drive_get_device_type ( const gchar *drive_path)
-{
+gchar * gw_drive_get_device_type ( const gchar *drive_path) {
 	gchar *device_type = NULL;
 #if !defined ( OS_FREEBSD) && !defined ( OS_OPENBSD) && !defined ( OS_NETBSD) && !defined ( OS_MACOS) && !defined ( OS_MACOSX) && !defined ( OS_DARWIN)
 	FILE *mtab = NULL;
@@ -884,77 +861,61 @@ gchar * gw_drive_get_device_type ( const gchar *drive_path)
 #endif
 
 	/* Opens the /etc/mtab file. */
-	if ( (mtab = setmntent ( "/etc/mtab", "r")) != NULL )
-	{
-		while ( ( partition = getmntent ( mtab)) != NULL )
-		{
-			if ( (partition->mnt_dir != NULL) && (strcmp ( partition->mnt_dir, drive_path) == 0) )
-			{
-				if ( (partition->mnt_type != NULL) && (strncmp ( "supermount", partition->mnt_type, 10) == 0) )
-				{
+	if ( (mtab = setmntent ( "/etc/mtab", "r")) != NULL ) {
+		while ( ( partition = getmntent ( mtab)) != NULL ) {
+			if ( (partition->mnt_dir != NULL) && (strcmp ( partition->mnt_dir, drive_path) == 0) ) {
+				if ( (partition->mnt_type != NULL) && ((strncmp ( "supermount", partition->mnt_type, 10) == 0)||(strncmp ( "subfs", partition->mnt_type, 5)==0)) ) {
 					/* Gets the mount options and search the option auto. */
-					if ( partition->mnt_opts != NULL )
-					{
+					if ( partition->mnt_opts != NULL ) {
 						options = g_strsplit ( partition->mnt_opts, ",", 0);
 
-						for ( i = 0; options[i] != NULL; i++)
-						{
-							if ( (strncmp ( options[i], "fs=", 3) == 0) && (fs_type == NULL) )
-							{
+						for ( i = 0; options[i] != NULL; i++) {
+							if ( (strncmp ( options[i], "fs=", 3) == 0) && (fs_type == NULL) ) {
 								fs_type = g_strsplit ( options[i], "=", 2);
 							}
 
-							if ( (strncmp ( options[i], "dev=", 4) == 0) && (fs_device == NULL) )
-							{
+							if ( (strncmp ( options[i], "dev=", 4) == 0) && (fs_device == NULL) ) {
 								fs_device = g_strsplit ( options[i], "=", 2);
 							}
 						}
-					}
-					else
-					{
+					} else {
 						/* Should we trait this error?? */
 					}
 
+					if ( fs_device == NULL && strncmp("subfs",partition->mnt_type,5) == 0 ) {
+						fs_device = (gchar**)g_malloc0(3*sizeof(gchar*));
+						fs_device[0] = g_strdup("");
+						fs_device[1] = g_strdup(partition->mnt_fsname);
+						fs_device[2] = NULL;
+					}
+
 					device_type = g_strdup_printf ( "%s [ %s ]", fs_device[1], fs_type[1]);
 
-					if ( fs_device != NULL )
-					{
+					if ( fs_device != NULL ) {
 						g_strfreev ( fs_device);
 						fs_device = NULL;
 					}
 
-					if ( fs_type != NULL )
-					{
+					if ( fs_type != NULL ) {
 						g_strfreev ( fs_type);
 						fs_type = NULL;
 					}
 
-					if ( options != NULL )
-					{
+					if ( options != NULL ) {
 						g_strfreev ( options);
 						options = NULL;
 					}
-				}
-				else { if ( strncmp ( "/dev/hd", partition->mnt_fsname, 7) == 0 )
-				{
+				} else if ( strncmp ( "/dev/hd", partition->mnt_fsname, 7) == 0 ) {
 					device_type = g_strdup_printf ( "HD [ %s ]", partition->mnt_type);
-				}
-				else { if ( strncmp ( "/dev/cdrom", partition->mnt_fsname, 10) == 0 )
-				{
+				} else if ( strncmp ( "/dev/cdrom", partition->mnt_fsname, 10) == 0 ) {
 					device_type = g_strdup_printf ( "CD-ROM [ %s ]", partition->mnt_type);
-				}
-				else { if ( strncmp ( "/dev/scd", partition->mnt_fsname, 8) == 0 )
-				{
+				} else if ( strncmp ( "/dev/scd", partition->mnt_fsname, 8) == 0 ) {
 					device_type = g_strdup_printf ( "CD-ROM [ %s ]", partition->mnt_type);
-				}
-				else { if ( strncmp ( "/dev/fd", partition->mnt_fsname, 7) == 0 )
-				{
+				} else if ( strncmp ( "/dev/fd", partition->mnt_fsname, 7) == 0 ) {
 					device_type = g_strdup_printf ( "Floppy [ %s ]", partition->mnt_type);
-				}
-				else
-				{
+				} else {
 					device_type = g_strdup ( partition->mnt_type);
-				}}}}}
+				}
 			}
 		}
 
@@ -962,85 +923,67 @@ gchar * gw_drive_get_device_type ( const gchar *drive_path)
 		endmntent ( mtab);
 	}
 
-	if ( device_type == NULL )
-	{
+	if ( device_type == NULL ) {
 		/* If the disk is not mounted. */
 		/* Opens the /etc/fstab file. */
-		if ( (fstab = setmntent ( "/etc/fstab", "r")) != NULL )
-		{
-			while ( ( partition = getmntent ( fstab)) != NULL )
-			{
-				if ( (partition->mnt_dir != NULL) && (strcmp ( partition->mnt_dir, drive_path) == 0) )
-				{
-					if ( (partition->mnt_type != NULL) && (strncmp ( "supermount", partition->mnt_type, 10) == 0) )
-					{
+		if ( (fstab = setmntent ( "/etc/fstab", "r")) != NULL ) {
+			while ( ( partition = getmntent ( fstab)) != NULL ) {
+				if ( (partition->mnt_dir != NULL) && (strcmp ( partition->mnt_dir, drive_path) == 0) ) {
+					if ( (partition->mnt_type != NULL) && ((strncmp ( "supermount", partition->mnt_type, 10) == 0)||(strncmp ( "subfs", partition->mnt_type, 5) == 0)) ) {
 						/* Gets the mount options and search the option auto. */
-						if ( partition->mnt_opts != NULL )
-						{
+						if ( partition->mnt_opts != NULL ) {
 							options = g_strsplit ( partition->mnt_opts, ",", 0);
 
-							for ( i = 0; options[i] != NULL; i++)
-							{
-								if ( (strncmp ( options[i], "fs=", 3) == 0) && (fs_type == NULL) )
-								{
+							for ( i = 0; options[i] != NULL; i++) {
+								if ( (strncmp ( options[i], "fs=", 3) == 0) && (fs_type == NULL) ) {
 									fs_type = g_strsplit ( options[i], "=", 2);
 								}
 
-								if ( (strncmp ( options[i], "dev=", 4) == 0) && (fs_device == NULL) )
-								{
+								if ( (strncmp ( options[i], "dev=", 4) == 0) && (fs_device == NULL) ) {
 									fs_device = g_strsplit ( options[i], "=", 2);
 								}
 							}
-						}
-						else
-						{
+						} else {
 							/* Should we trait this error?? */
 						}
 
+						if ( fs_device == NULL && strncmp("subfs",partition->mnt_type,5) == 0 ) {
+							fs_device = (gchar**)g_malloc0(3*sizeof(gchar*));
+							fs_device[0] = g_strdup("");
+							fs_device[1] = g_strdup(partition->mnt_fsname);
+							fs_device[2] = NULL;
+						}
+
 						device_type = g_strdup_printf ( "%s [ %s ]", fs_device[1], fs_type[1]);
 
-						if ( fs_device != NULL )
-						{
+						if ( fs_device != NULL ) {
 							g_strfreev ( fs_device);
 							fs_device = NULL;
 						}
 
-						if ( fs_type != NULL )
-						{
+						if ( fs_type != NULL ) {
 							g_strfreev ( fs_type);
 							fs_type = NULL;
 						}
 
-						if ( options != NULL )
-						{
+						if ( options != NULL ) {
 							g_strfreev ( options);
 							options = NULL;
 						}
 					}
-					else { if ( strncmp ( "/dev/hd", partition->mnt_fsname, 7) == 0 )
-					{
+					else if ( strncmp ( "/dev/hd", partition->mnt_fsname, 7) == 0 ) {
 						device_type = g_strdup_printf ( "HD [ %s ]", partition->mnt_type);
-					}
-					else { if ( strncmp ( "/dev/cdrom", partition->mnt_fsname, 10) == 0 )
-					{
+					} else if ( strncmp ( "/dev/cdrom", partition->mnt_fsname, 10) == 0 ) {
 						device_type = g_strdup_printf ( "CD-ROM [ %s ]", partition->mnt_type);
-					}
-					else { if ( strncmp ( "/dev/scd", partition->mnt_fsname, 8) == 0 )
-					{
+					} else if ( strncmp ( "/dev/scd", partition->mnt_fsname, 8) == 0 ) {
 						device_type = g_strdup_printf ( "CD-ROM [ %s ]", partition->mnt_type);
-					}
-					else { if ( strncmp ( "/dev/fd", partition->mnt_fsname, 7) == 0 )
-					{
+					} else if ( strncmp ( "/dev/fd", partition->mnt_fsname, 7) == 0 ) {
 						device_type = g_strdup_printf ( "Floppy [ %s ]", partition->mnt_type);
-					}
-					else { if ( strncmp ( "/dev/zip", partition->mnt_fsname, 8) == 0 )
-					{
+					} else if ( strncmp ( "/dev/zip", partition->mnt_fsname, 8) == 0 ) {
 						device_type = g_strdup_printf ( "Zip [ %s ]", partition->mnt_type);
-					}
-					else
-					{
+					} else {
 						device_type = g_strdup ( partition->mnt_type);
-					}}}}}}
+					}
 				}
 			}
 
@@ -1059,28 +1002,17 @@ gchar * gw_drive_get_device_type ( const gchar *drive_path)
 	/* Opens the /etc/fstab file. */
 	setfsent ( );
 
-	while ( (partition = getfsent ( )) != NULL)
-	{
-		if ( (partition->fs_spec != NULL) && (partition->fs_vfstype != NULL) )
-		{
-			if ( strncmp ( "/dev/ad", partition->fs_spec, 7) == 0 )
-			{
+	while ( (partition = getfsent ( )) != NULL) {
+		if ( (partition->fs_spec != NULL) && (partition->fs_vfstype != NULL) ) {
+			if ( strncmp ( "/dev/ad", partition->fs_spec, 7) == 0 ) {
 				device_type = g_strdup_printf ( "HD [ %s ]", partition->fs_vfstype);
-			}
-			else if ( strncmp ( "/dev/acd", partition->fs_spec, 8) == 0 )
-			{
+			} else if ( strncmp ( "/dev/acd", partition->fs_spec, 8) == 0 ) {
 				device_type = g_strdup_printf ( "CD-ROM [ %s ]", partition->fs_vfstype);
-			}
-			else if ( strncmp ( "/dev/scd", partition->fs_spec, 8) == 0 )
-			{
+			} else if ( strncmp ( "/dev/scd", partition->fs_spec, 8) == 0 ) {
 				device_type = g_strdup_printf ( "CD-ROM [ %s ]", partition->fs_vfstype);
-			}
-			else if ( strncmp ( "/dev/fd", partition->fs_spec, 7) == 0 )
-			{
+			} else if ( strncmp ( "/dev/fd", partition->fs_spec, 7) == 0 ) {
 				device_type = g_strdup_printf ( "Floppy [ %s ]", partition->fs_vfstype);
-			}
-			else
-			{
+			} else {
 				device_type = g_strdup ( partition->fs_vfstype);
 			}
 		}
@@ -1094,8 +1026,7 @@ gchar * gw_drive_get_device_type ( const gchar *drive_path)
 }
 
 
-gchar * gw_drive_get_device_name ( const gchar *drive_path)
-{
+gchar * gw_drive_get_device_name ( const gchar *drive_path) {
 	gchar * device_name = NULL;
 #if !defined ( OS_FREEBSD) && !defined ( OS_OPENBSD) && !defined ( OS_NETBSD) && !defined ( OS_MACOS) && !defined ( OS_MACOSX) && !defined ( OS_DARWIN)
 	FILE *tab = NULL;
@@ -1110,25 +1041,18 @@ gchar * gw_drive_get_device_name ( const gchar *drive_path)
 #endif
 
 	/* Opens only the /etc/mtab file because the result must be returned only if the drive is mounted. */
-	if ( (tab = setmntent ( "/etc/mtab", "r")) != NULL )
-	{
-		while ( (partition = getmntent ( tab)) != NULL)
-		{
-			if ( (partition->mnt_dir != NULL) && (strcmp ( partition->mnt_dir, drive_path) == 0) )
-			{
-				if ( (partition->mnt_type != NULL) && (strncmp ( "supermount", partition->mnt_type, 10) == 0) )
-				{
+	if ( (tab = setmntent ( "/etc/mtab", "r")) != NULL ) {
+		while ( (partition = getmntent ( tab)) != NULL) {
+			if ( (partition->mnt_dir != NULL) && (strcmp ( partition->mnt_dir, drive_path) == 0) ) {
+//				if ( (partition->mnt_type != NULL) && ((strncmp ( "supermount", partition->mnt_type, 10) == 0)||(strncmp ( "subfs", partition->mnt_type, 5) == 0)) ) {
+				if ( (partition->mnt_type != NULL) && (strncmp ( "supermount", partition->mnt_type, 10) == 0)) {
 					/* Gets the mount options and search the option auto. */
-					if ( partition->mnt_opts != NULL )
-					{
+					if ( partition->mnt_opts != NULL ) {
 						options = g_strsplit ( partition->mnt_opts, ",", 0);
 
-						for ( i = 0; options[i] != NULL; i++)
-						{
-							if ( strncmp ( options[i], "dev=", 4) == 0 )
-							{
-								if ( (fs_device = g_strsplit ( options[i], "=", 2)) != NULL )
-								{
+						for ( i = 0; options[i] != NULL; i++) {
+							if ( strncmp ( options[i], "dev=", 4) == 0 ) {
+								if ( (fs_device = g_strsplit ( options[i], "=", 2)) != NULL ) {
 									device_name = g_strdup ( fs_device[1]);
 
 									g_strfreev ( fs_device);
@@ -1136,20 +1060,17 @@ gchar * gw_drive_get_device_name ( const gchar *drive_path)
 								}
 							}
 						}
-					}
-					else
-					{
+					} else {
 						/* Should we trait this error?? */
 					}
 
-					if ( options != NULL )
-					{
+					if ( options != NULL ) {
 						g_strfreev ( options);
 						options = NULL;
 					}
+				} else {
+					device_name = g_strdup ( partition->mnt_fsname);
 				}
-
-				device_name = g_strdup ( partition->mnt_fsname);
 			}
 		}
 
@@ -1167,10 +1088,8 @@ gchar * gw_drive_get_device_name ( const gchar *drive_path)
 	/* Get list of mounted devices. */
 	int i, mfs_count = getmntinfo ( &pstats, MNT_WAIT);
 
-	for ( i = 0; i < mfs_count; i++)
-	{
-		if ( (pstats[i].f_mntonname != NULL) && (strcmp ( pstats[i].f_mntonname, drive_path) == 0) )
-		{
+	for ( i = 0; i < mfs_count; i++) {
+		if ( (pstats[i].f_mntonname != NULL) && (strcmp ( pstats[i].f_mntonname, drive_path) == 0) ) {
 			device_name = g_strdup ( pstats[i].f_mntfromname);
 			break;
 		}
