@@ -24,6 +24,7 @@
 #include <string.h> /* strcmp strlen memmove strstr strncmp strerror memcpy */
 #include <ctype.h> /* isspace*/
 #include <regex.h> /* regcomp regexec */
+#include <stdlib.h> /* abs */
 
 
 #ifndef strsep
@@ -1280,3 +1281,27 @@ gint gintlen ( const gint n)
 
 	return len;
 }
+
+
+gchar * gw_time_to_str ( gulong t, const gchar *format) {
+	struct tm *time = NULL;
+	gchar *date = NULL;
+
+
+	if ( t != 0 ) {
+		if ( (time = localtime ( &t)) != NULL ) {
+			if ( (date = (gchar*)g_malloc ( sizeof ( gchar) * 20)) != NULL ) {
+				strftime ( date, 20, format, time);
+
+				return date;
+			} else {}
+		} else {}
+	} else {}
+
+	return NULL;
+}
+
+
+gchar * gw_time_to_str_df ( gulong t) {
+	return gw_time_to_str ( t, DATE_FORMAT);
+}
